"""The zoom commands module.

These commands are used in the following models:
DPO4K, DPO4KB, MDO3, MDO3K, MDO4K, MDO4KB, MDO4KC, MSO4K, MSO4KB

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:
    ```
    - ZOOm:MODe {ON|OFF|<NR1>}
    - ZOOm:STATE {ON|OFF|<NR1>}
    - ZOOm:ZOOM1:FACtor?
    - ZOOm:ZOOM1:HORizontal:POSition <NR3>
    - ZOOm:ZOOM1:HORizontal:POSition?
    - ZOOm:ZOOM1:HORizontal:SCAle <NR3>
    - ZOOm:ZOOM1:HORizontal:SCAle?
    - ZOOm:ZOOM1:POSition <NR3>
    - ZOOm:ZOOM1:POSition?
    - ZOOm:ZOOM1:SCAle <NR3>
    - ZOOm:ZOOM1:SCAle?
    - ZOOm:ZOOM1:STATE {ON|OFF|<NR1>}
    - ZOOm:ZOOM1:STATE?
    - ZOOm:ZOOM1:TRIGPOS?
    - ZOOm:ZOOM1?
    - ZOOm?
    ```
"""

from typing import Optional, TYPE_CHECKING

from ..helpers import SCPICmdRead, SCPICmdWrite

if TYPE_CHECKING:
    from tm_devices.driver_mixins.device_control.pi_control import PIControl


class ZoomZoom1Trigpos(SCPICmdRead):
    """The ``ZOOm:ZOOM1:TRIGPOS`` command.

    Description:
        - This query returns the time at the center of the zoom box relative to the trigger position
          of the currently selected time domain waveform.

    Usage:
        - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:TRIGPOS?`` query.
        - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:TRIGPOS?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - ZOOm:ZOOM1:TRIGPOS?
        ```
    """


class ZoomZoom1State(SCPICmdWrite, SCPICmdRead):
    """The ``ZOOm:ZOOM1:STATE`` command.

    Description:
        - This command turns the specified zoom on or off. <x> can only be 1.

    Usage:
        - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:STATE?`` query.
        - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:STATE?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ZOOm:ZOOM1:STATE value`` command.

    SCPI Syntax:
        ```
        - ZOOm:ZOOM1:STATE {ON|OFF|<NR1>}
        - ZOOm:ZOOM1:STATE?
        ```

    Info:
        - ``ON`` turns Zoom 1 on.
        - ``OFF`` turns Zoom 1 off.
        - ``<NR1>`` is an integer. 0 disables the specified zoom; any other value enables the
          specified zoom.
    """


class ZoomZoom1Scale(SCPICmdWrite, SCPICmdRead):
    """The ``ZOOm:ZOOM1:SCAle`` command.

    Description:
        - This command specifies the horizontal scale of the zoom box. <x> can only be 1.

    Usage:
        - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:SCAle?`` query.
        - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:SCAle?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ZOOm:ZOOM1:SCAle value`` command.

    SCPI Syntax:
        ```
        - ZOOm:ZOOM1:SCAle <NR3>
        - ZOOm:ZOOM1:SCAle?
        ```

    Info:
        - ``<NR3>`` is a floating point number that specifies the horizontal scale of the zoom box.
    """


class ZoomZoom1Position(SCPICmdWrite, SCPICmdRead):
    """The ``ZOOm:ZOOM1:POSition`` command.

    Description:
        - Sets the horizontal position of the zoom box, in terms of 0 to 100.0% of upper window. <x>
          can only be 1.

    Usage:
        - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:POSition?`` query.
        - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:POSition?`` query and raise
          an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ZOOm:ZOOM1:POSition value`` command.

    SCPI Syntax:
        ```
        - ZOOm:ZOOM1:POSition <NR3>
        - ZOOm:ZOOM1:POSition?
        ```

    Info:
        - ``<NR3>`` is a floating point number that specifies the horizontal position as a percent
          of the upper window.
    """


class ZoomZoom1HorizontalScale(SCPICmdWrite, SCPICmdRead):
    """The ``ZOOm:ZOOM1:HORizontal:SCAle`` command.

    Description:
        - This command specifies the zoom horizontal scale factor for the specified zoom, where x is
          the integer 1 representing the single zoom window. <x> can only be 1.

    Usage:
        - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:HORizontal:SCAle?`` query.
        - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:HORizontal:SCAle?`` query
          and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ZOOm:ZOOM1:HORizontal:SCAle value``
          command.

    SCPI Syntax:
        ```
        - ZOOm:ZOOM1:HORizontal:SCAle <NR3>
        - ZOOm:ZOOM1:HORizontal:SCAle?
        ```

    Info:
        - ``<NR3>`` is the amount of expansion in the horizontal direction in 1-2 -5 increments.
    """


class ZoomZoom1HorizontalPosition(SCPICmdWrite, SCPICmdRead):
    """The ``ZOOm:ZOOM1:HORizontal:POSition`` command.

    Description:
        - This command specifies the horizontal position for the specified zoom, where x is the
          integer 1 representing the single zoom window. <x> can only be 1.

    Usage:
        - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:HORizontal:POSition?`` query.
        - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:HORizontal:POSition?``
          query and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ZOOm:ZOOM1:HORizontal:POSition value``
          command.

    SCPI Syntax:
        ```
        - ZOOm:ZOOM1:HORizontal:POSition <NR3>
        - ZOOm:ZOOM1:HORizontal:POSition?
        ```

    Info:
        - ``<NR3>`` is a value from 0 to 100.00 and is the percent of the upper window that is to
          the left of screen center, when the zoom factor is 1× or greater.
    """


class ZoomZoom1Horizontal(SCPICmdRead):
    """The ``ZOOm:ZOOM1:HORizontal`` command tree.

    Usage:
        - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:HORizontal?`` query.
        - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:HORizontal?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.position``: The ``ZOOm:ZOOM1:HORizontal:POSition`` command.
        - ``.scale``: The ``ZOOm:ZOOM1:HORizontal:SCAle`` command.
    """

    def __init__(self, device: Optional["PIControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._position = ZoomZoom1HorizontalPosition(device, f"{self._cmd_syntax}:POSition")
        self._scale = ZoomZoom1HorizontalScale(device, f"{self._cmd_syntax}:SCAle")

    @property
    def position(self) -> ZoomZoom1HorizontalPosition:
        """Return the ``ZOOm:ZOOM1:HORizontal:POSition`` command.

        Description:
            - This command specifies the horizontal position for the specified zoom, where x is the
              integer 1 representing the single zoom window. <x> can only be 1.

        Usage:
            - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:HORizontal:POSition?`` query.
            - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:HORizontal:POSition?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the
              ``ZOOm:ZOOM1:HORizontal:POSition value`` command.

        SCPI Syntax:
            ```
            - ZOOm:ZOOM1:HORizontal:POSition <NR3>
            - ZOOm:ZOOM1:HORizontal:POSition?
            ```

        Info:
            - ``<NR3>`` is a value from 0 to 100.00 and is the percent of the upper window that is
              to the left of screen center, when the zoom factor is 1× or greater.
        """
        return self._position

    @property
    def scale(self) -> ZoomZoom1HorizontalScale:
        """Return the ``ZOOm:ZOOM1:HORizontal:SCAle`` command.

        Description:
            - This command specifies the zoom horizontal scale factor for the specified zoom, where
              x is the integer 1 representing the single zoom window. <x> can only be 1.

        Usage:
            - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:HORizontal:SCAle?`` query.
            - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:HORizontal:SCAle?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ZOOm:ZOOM1:HORizontal:SCAle value``
              command.

        SCPI Syntax:
            ```
            - ZOOm:ZOOM1:HORizontal:SCAle <NR3>
            - ZOOm:ZOOM1:HORizontal:SCAle?
            ```

        Info:
            - ``<NR3>`` is the amount of expansion in the horizontal direction in 1-2 -5 increments.
        """
        return self._scale


class ZoomZoom1Factor(SCPICmdRead):
    """The ``ZOOm:ZOOM1:FACtor`` command.

    Description:
        - Returns the zoom factor of a particular zoom box. <x> can only be 1.

    Usage:
        - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:FACtor?`` query.
        - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:FACtor?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - ZOOm:ZOOM1:FACtor?
        ```
    """


class ZoomZoom1(SCPICmdRead):
    """The ``ZOOm:ZOOM1`` command.

    Description:
        - Returns the current vertical and horizontal positioning and scaling of the display. <x>
          can only be 1.

    Usage:
        - Using the ``.query()`` method will send the ``ZOOm:ZOOM1?`` query.
        - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - ZOOm:ZOOM1?
        ```

    Properties:
        - ``.factor``: The ``ZOOm:ZOOM1:FACtor`` command.
        - ``.horizontal``: The ``ZOOm:ZOOM1:HORizontal`` command tree.
        - ``.position``: The ``ZOOm:ZOOM1:POSition`` command.
        - ``.scale``: The ``ZOOm:ZOOM1:SCAle`` command.
        - ``.state``: The ``ZOOm:ZOOM1:STATE`` command.
        - ``.trigpos``: The ``ZOOm:ZOOM1:TRIGPOS`` command.
    """

    def __init__(self, device: Optional["PIControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._factor = ZoomZoom1Factor(device, f"{self._cmd_syntax}:FACtor")
        self._horizontal = ZoomZoom1Horizontal(device, f"{self._cmd_syntax}:HORizontal")
        self._position = ZoomZoom1Position(device, f"{self._cmd_syntax}:POSition")
        self._scale = ZoomZoom1Scale(device, f"{self._cmd_syntax}:SCAle")
        self._state = ZoomZoom1State(device, f"{self._cmd_syntax}:STATE")
        self._trigpos = ZoomZoom1Trigpos(device, f"{self._cmd_syntax}:TRIGPOS")

    @property
    def factor(self) -> ZoomZoom1Factor:
        """Return the ``ZOOm:ZOOM1:FACtor`` command.

        Description:
            - Returns the zoom factor of a particular zoom box. <x> can only be 1.

        Usage:
            - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:FACtor?`` query.
            - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:FACtor?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - ZOOm:ZOOM1:FACtor?
            ```
        """
        return self._factor

    @property
    def horizontal(self) -> ZoomZoom1Horizontal:
        """Return the ``ZOOm:ZOOM1:HORizontal`` command tree.

        Usage:
            - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:HORizontal?`` query.
            - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:HORizontal?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.position``: The ``ZOOm:ZOOM1:HORizontal:POSition`` command.
            - ``.scale``: The ``ZOOm:ZOOM1:HORizontal:SCAle`` command.
        """
        return self._horizontal

    @property
    def position(self) -> ZoomZoom1Position:
        """Return the ``ZOOm:ZOOM1:POSition`` command.

        Description:
            - Sets the horizontal position of the zoom box, in terms of 0 to 100.0% of upper window.
              <x> can only be 1.

        Usage:
            - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:POSition?`` query.
            - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:POSition?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ZOOm:ZOOM1:POSition value``
              command.

        SCPI Syntax:
            ```
            - ZOOm:ZOOM1:POSition <NR3>
            - ZOOm:ZOOM1:POSition?
            ```

        Info:
            - ``<NR3>`` is a floating point number that specifies the horizontal position as a
              percent of the upper window.
        """
        return self._position

    @property
    def scale(self) -> ZoomZoom1Scale:
        """Return the ``ZOOm:ZOOM1:SCAle`` command.

        Description:
            - This command specifies the horizontal scale of the zoom box. <x> can only be 1.

        Usage:
            - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:SCAle?`` query.
            - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:SCAle?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ZOOm:ZOOM1:SCAle value`` command.

        SCPI Syntax:
            ```
            - ZOOm:ZOOM1:SCAle <NR3>
            - ZOOm:ZOOM1:SCAle?
            ```

        Info:
            - ``<NR3>`` is a floating point number that specifies the horizontal scale of the zoom
              box.
        """
        return self._scale

    @property
    def state(self) -> ZoomZoom1State:
        """Return the ``ZOOm:ZOOM1:STATE`` command.

        Description:
            - This command turns the specified zoom on or off. <x> can only be 1.

        Usage:
            - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:STATE?`` query.
            - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:STATE?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ZOOm:ZOOM1:STATE value`` command.

        SCPI Syntax:
            ```
            - ZOOm:ZOOM1:STATE {ON|OFF|<NR1>}
            - ZOOm:ZOOM1:STATE?
            ```

        Info:
            - ``ON`` turns Zoom 1 on.
            - ``OFF`` turns Zoom 1 off.
            - ``<NR1>`` is an integer. 0 disables the specified zoom; any other value enables the
              specified zoom.
        """
        return self._state

    @property
    def trigpos(self) -> ZoomZoom1Trigpos:
        """Return the ``ZOOm:ZOOM1:TRIGPOS`` command.

        Description:
            - This query returns the time at the center of the zoom box relative to the trigger
              position of the currently selected time domain waveform.

        Usage:
            - Using the ``.query()`` method will send the ``ZOOm:ZOOM1:TRIGPOS?`` query.
            - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1:TRIGPOS?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - ZOOm:ZOOM1:TRIGPOS?
            ```
        """
        return self._trigpos


class ZoomState(SCPICmdWrite):
    """The ``ZOOm:STATE`` command.

    Description:
        - Turns Zoom mode on or off. The Zoom query returns the current state of Zoom mode. This
          command is equivalent to pressing the zoom button located on the front panel.

    Usage:
        - Using the ``.write(value)`` method will send the ``ZOOm:STATE value`` command.

    SCPI Syntax:
        ```
        - ZOOm:STATE {ON|OFF|<NR1>}
        ```

    Info:
        - ``ON`` turns on Zoom mode.
        - ``OFF`` turns off Zoom mode.
        - ``<NR1>`` is an integer. 0 turns off Zoom mode; any other value turns on Zoom mode.
    """


class ZoomMode(SCPICmdWrite):
    """The ``ZOOm:MODe`` command.

    Description:
        - Turns Zoom mode on or off. The Zoom query returns the current state of Zoom mode. This
          command is equivalent to pressing the zoom button located on the front panel.

    Usage:
        - Using the ``.write(value)`` method will send the ``ZOOm:MODe value`` command.

    SCPI Syntax:
        ```
        - ZOOm:MODe {ON|OFF|<NR1>}
        ```

    Info:
        - ``ON`` turns on Zoom mode.
        - ``OFF`` turns off Zoom mode.
        - ``<NR1>`` is an integer. 0 turns off Zoom mode; any other value turns on Zoom mode.
    """


class Zoom(SCPICmdRead):
    """The ``ZOOm`` command.

    Description:
        - Returns the current vertical and horizontal positioning and scaling of the display.

    Usage:
        - Using the ``.query()`` method will send the ``ZOOm?`` query.
        - Using the ``.verify(value)`` method will send the ``ZOOm?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - ZOOm?
        ```

    Properties:
        - ``.zoom1``: The ``ZOOm:ZOOM1`` command.
        - ``.mode``: The ``ZOOm:MODe`` command.
        - ``.state``: The ``ZOOm:STATE`` command.
    """

    def __init__(self, device: Optional["PIControl"] = None, cmd_syntax: str = "ZOOm") -> None:
        super().__init__(device, cmd_syntax)
        self._zoom1 = ZoomZoom1(device, f"{self._cmd_syntax}:ZOOM1")
        self._mode = ZoomMode(device, f"{self._cmd_syntax}:MODe")
        self._state = ZoomState(device, f"{self._cmd_syntax}:STATE")

    @property
    def zoom1(self) -> ZoomZoom1:
        """Return the ``ZOOm:ZOOM1`` command.

        Description:
            - Returns the current vertical and horizontal positioning and scaling of the display.
              <x> can only be 1.

        Usage:
            - Using the ``.query()`` method will send the ``ZOOm:ZOOM1?`` query.
            - Using the ``.verify(value)`` method will send the ``ZOOm:ZOOM1?`` query and raise an
              AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - ZOOm:ZOOM1?
            ```

        Sub-properties:
            - ``.factor``: The ``ZOOm:ZOOM1:FACtor`` command.
            - ``.horizontal``: The ``ZOOm:ZOOM1:HORizontal`` command tree.
            - ``.position``: The ``ZOOm:ZOOM1:POSition`` command.
            - ``.scale``: The ``ZOOm:ZOOM1:SCAle`` command.
            - ``.state``: The ``ZOOm:ZOOM1:STATE`` command.
            - ``.trigpos``: The ``ZOOm:ZOOM1:TRIGPOS`` command.
        """
        return self._zoom1

    @property
    def mode(self) -> ZoomMode:
        """Return the ``ZOOm:MODe`` command.

        Description:
            - Turns Zoom mode on or off. The Zoom query returns the current state of Zoom mode. This
              command is equivalent to pressing the zoom button located on the front panel.

        Usage:
            - Using the ``.write(value)`` method will send the ``ZOOm:MODe value`` command.

        SCPI Syntax:
            ```
            - ZOOm:MODe {ON|OFF|<NR1>}
            ```

        Info:
            - ``ON`` turns on Zoom mode.
            - ``OFF`` turns off Zoom mode.
            - ``<NR1>`` is an integer. 0 turns off Zoom mode; any other value turns on Zoom mode.
        """
        return self._mode

    @property
    def state(self) -> ZoomState:
        """Return the ``ZOOm:STATE`` command.

        Description:
            - Turns Zoom mode on or off. The Zoom query returns the current state of Zoom mode. This
              command is equivalent to pressing the zoom button located on the front panel.

        Usage:
            - Using the ``.write(value)`` method will send the ``ZOOm:STATE value`` command.

        SCPI Syntax:
            ```
            - ZOOm:STATE {ON|OFF|<NR1>}
            ```

        Info:
            - ``ON`` turns on Zoom mode.
            - ``OFF`` turns off Zoom mode.
            - ``<NR1>`` is an integer. 0 turns off Zoom mode; any other value turns on Zoom mode.
        """
        return self._state



# pyright: reportConstantRedefinition=none
"""The display commands module.

These commands are used in the following models:
SMU2604B, SMU2614B, SMU2634B

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Attributes and Functions:
    ```
    - display.clear()
    - display.getannunciators()
    - display.getcursor()
    - display.getlastkey()
    - display.gettext()
    - display.inputvalue()
    - display.loadmenu.add()
    - display.loadmenu.delete()
    - display.locallockout
    - display.menu()
    - display.numpad
    - display.prompt()
    - display.screen
    - display.sendkey()
    - display.setcursor()
    - display.settext()
    - display.smuX.digits
    - display.smuX.limit.func
    - display.smuX.measure.func
    - display.trigger.clear()
    - display.trigger.overrun
    - display.trigger.wait()
    - display.waitkey()
    ```
"""

from typing import Dict, Optional, TYPE_CHECKING, Union

from ..helpers import (
    BaseTSPCmd,
    DefaultDictPassKeyToFactory,
    NoDeviceProvidedError,
    ValidatedChannel,
)

if TYPE_CHECKING:
    from tm_devices.driver_mixins.device_control.tsp_control import TSPControl


class DisplayTrigger(BaseTSPCmd):
    """The ``display.trigger`` command tree.

    Constants:
        - ``.EVENT_ID``: The event ID of the event generated when the front-panel TRIG key is
          pressed.

    Properties and methods:
        - ``.clear()``: The ``display.trigger.clear()`` function.
        - ``.overrun``: The ``display.trigger.overrun`` attribute.
        - ``.wait()``: The ``display.trigger.wait()`` function.
    """

    EVENT_ID = "display.trigger.EVENT_ID"
    """str: The event ID of the event generated when the front-panel TRIG key is pressed."""

    @property
    def overrun(self) -> str:
        """Access the ``display.trigger.overrun`` attribute.

        Description:
            - This attribute contains the event detector overrun status.

        Usage:
            - Accessing this property will send the ``print(display.trigger.overrun)`` query.

        TSP Syntax:
            ```
            - print(display.trigger.overrun)
            ```

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".overrun"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.overrun)"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to access the ``{self._cmd_syntax}.overrun`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def clear(self) -> None:
        """Run the ``display.trigger.clear()`` function.

        Description:
            - This function clears the front-panel trigger event detector.

        TSP Syntax:
            ```
            - display.trigger.clear()
            ```

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(  # type: ignore[union-attr]
                f"{self._cmd_syntax}.clear()"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.clear()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def wait(self, timeout: float) -> str:
        """Run the ``display.trigger.wait()`` function.

        Description:
            - This function waits for the TRIG key on the front panel to be pressed.

        TSP Syntax:
            ```
            - display.trigger.wait()
            ```

        Args:
            timeout: Timeout in seconds.

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.wait({timeout}))"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.wait()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error


class DisplaySmuxItemMeasure(BaseTSPCmd):
    """The ``display.smuX.measure`` command tree.

    Info:
        - ``X``, the source-measure unit (SMU) channel (for example, display.smua.measure.func
          applies to SMU channel A).

    Properties and methods:
        - ``.func``: The ``display.smuX.measure.func`` attribute.
    """

    @property
    def func(self) -> str:
        """Access the ``display.smuX.measure.func`` attribute.

        Description:
            - This attribute specifies the type of measurement that is being displayed.

        Usage:
            - Accessing this property will send the ``print(display.smuX.measure.func)`` query.
            - Setting this property to a value will send the ``display.smuX.measure.func = value``
              command.

        TSP Syntax:
            ```
            - display.smuX.measure.func = value
            - print(display.smuX.measure.func)
            ```

        Info:
            - ``X``, the source-measure unit (SMU) channel (for example, display.smua.measure.func
              applies to SMU channel A).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".func"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.func)"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to access the ``{self._cmd_syntax}.func`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @func.setter
    def func(self, value: Union[str, float]) -> None:
        """Access the ``display.smuX.measure.func`` attribute.

        Description:
            - This attribute specifies the type of measurement that is being displayed.

        Usage:
            - Accessing this property will send the ``print(display.smuX.measure.func)`` query.
            - Setting this property to a value will send the ``display.smuX.measure.func = value``
              command.

        TSP Syntax:
            ```
            - display.smuX.measure.func = value
            - print(display.smuX.measure.func)
            ```

        Info:
            - ``X``, the source-measure unit (SMU) channel (for example, display.smua.measure.func
              applies to SMU channel A).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".func", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.func = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to access the ``{self._cmd_syntax}.func`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error


class DisplaySmuxItemLimit(BaseTSPCmd):
    """The ``display.smuX.limit`` command tree.

    Info:
        - ``X``, the source-measure unit (SMU) channel (for example, display.smua.limit.func applies
          to SMU channel A).

    Properties and methods:
        - ``.func``: The ``display.smuX.limit.func`` attribute.
    """

    @property
    def func(self) -> str:
        """Access the ``display.smuX.limit.func`` attribute.

        Description:
            - If you are using a display mode that shows a single channel, this attribute specifies
              the type of limit value setting displayed.

        Usage:
            - Accessing this property will send the ``print(display.smuX.limit.func)`` query.
            - Setting this property to a value will send the ``display.smuX.limit.func = value``
              command.

        TSP Syntax:
            ```
            - display.smuX.limit.func = value
            - print(display.smuX.limit.func)
            ```

        Info:
            - ``X``, the source-measure unit (SMU) channel (for example, display.smua.limit.func
              applies to SMU channel A).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".func"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.func)"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to access the ``{self._cmd_syntax}.func`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @func.setter
    def func(self, value: Union[str, float]) -> None:
        """Access the ``display.smuX.limit.func`` attribute.

        Description:
            - If you are using a display mode that shows a single channel, this attribute specifies
              the type of limit value setting displayed.

        Usage:
            - Accessing this property will send the ``print(display.smuX.limit.func)`` query.
            - Setting this property to a value will send the ``display.smuX.limit.func = value``
              command.

        TSP Syntax:
            ```
            - display.smuX.limit.func = value
            - print(display.smuX.limit.func)
            ```

        Info:
            - ``X``, the source-measure unit (SMU) channel (for example, display.smua.limit.func
              applies to SMU channel A).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".func", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.func = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to access the ``{self._cmd_syntax}.func`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error


class DisplaySmuxItem(ValidatedChannel, BaseTSPCmd):
    """The ``display.smuX`` command tree.

    Info:
        - ``X``, the source-measure unit (SMU) channel (for example, display.smua.digits applies to
          SMU channel A).

    Properties and methods:
        - ``.digits``: The ``display.smuX.digits`` attribute.
        - ``.limit``: The ``display.smuX.limit`` command tree.
        - ``.measure``: The ``display.smuX.measure`` command tree.
    """

    def __init__(self, device: Optional["TSPControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._limit = DisplaySmuxItemLimit(device, f"{self._cmd_syntax}.limit")
        self._measure = DisplaySmuxItemMeasure(device, f"{self._cmd_syntax}.measure")

    @property
    def digits(self) -> str:
        """Access the ``display.smuX.digits`` attribute.

        Description:
            - This attribute sets the front-panel display resolution of the selected measurement.

        Usage:
            - Accessing this property will send the ``print(display.smuX.digits)`` query.
            - Setting this property to a value will send the ``display.smuX.digits = value``
              command.

        TSP Syntax:
            ```
            - display.smuX.digits = value
            - print(display.smuX.digits)
            ```

        Info:
            - ``X``, the source-measure unit (SMU) channel (for example, display.smua.digits applies
              to SMU channel A).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".digits"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.digits)"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to access the ``{self._cmd_syntax}.digits`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @digits.setter
    def digits(self, value: Union[str, float]) -> None:
        """Access the ``display.smuX.digits`` attribute.

        Description:
            - This attribute sets the front-panel display resolution of the selected measurement.

        Usage:
            - Accessing this property will send the ``print(display.smuX.digits)`` query.
            - Setting this property to a value will send the ``display.smuX.digits = value``
              command.

        TSP Syntax:
            ```
            - display.smuX.digits = value
            - print(display.smuX.digits)
            ```

        Info:
            - ``X``, the source-measure unit (SMU) channel (for example, display.smua.digits applies
              to SMU channel A).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".digits", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.digits = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to access the ``{self._cmd_syntax}.digits`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def limit(self) -> DisplaySmuxItemLimit:
        """Return the ``display.smuX.limit`` command tree.

        Info:
            - ``X``, the source-measure unit (SMU) channel (for example, display.smua.limit.func
              applies to SMU channel A).

        Sub-properties and sub-methods:
            - ``.func``: The ``display.smuX.limit.func`` attribute.
        """
        return self._limit

    @property
    def measure(self) -> DisplaySmuxItemMeasure:
        """Return the ``display.smuX.measure`` command tree.

        Info:
            - ``X``, the source-measure unit (SMU) channel (for example, display.smua.measure.func
              applies to SMU channel A).

        Sub-properties and sub-methods:
            - ``.func``: The ``display.smuX.measure.func`` attribute.
        """
        return self._measure


class DisplayLoadmenu(BaseTSPCmd):
    """The ``display.loadmenu`` command tree.

    Properties and methods:
        - ``.add()``: The ``display.loadmenu.add()`` function.
        - ``.delete()``: The ``display.loadmenu.delete()`` function.
    """

    def add(self, display_name: str, code: str, memory: Optional[str] = None) -> None:
        """Run the ``display.loadmenu.add()`` function.

        Description:
            - This function adds an entry to the USER menu, which can be accessed by pressing the
              LOAD key on the front panel.

        TSP Syntax:
            ```
            - display.loadmenu.add()
            ```

        Args:
            display_name: The name that is added to the USER menu.
            code: The code that is run from the USER menu.
            memory (optional): Determines if code is saved to nonvolatile memory.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            function_args = ", ".join(
                str(x)
                for x in (
                    f'"{display_name}"',
                    f'"{code}"',
                    memory,
                )
                if x is not None
            )
            self._device.write(  # type: ignore[union-attr]
                f"{self._cmd_syntax}.add({function_args})"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.add()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def delete(self, display_name: str) -> None:
        """Run the ``display.loadmenu.delete()`` function.

        Description:
            - This function removes an entry from the USER menu, which can be accessed using the
              LOAD key on the front panel.

        TSP Syntax:
            ```
            - display.loadmenu.delete()
            ```

        Args:
            display_name: The name to be deleted from the USER menu.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(  # type: ignore[union-attr]
                f'{self._cmd_syntax}.delete("{display_name}")'
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.delete()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error


class Display(BaseTSPCmd):
    """The ``display`` command tree.

    Constants:
        - ``.ANNUNCIATOR_4_WIRE``: 4W indicator on.
        - ``.ANNUNCIATOR_ARM``: ARM indicator on.
        - ``.ANNUNCIATOR_AUTO``: AUTO indicator on.
        - ``.ANNUNCIATOR_EDIT``: EDIT indicator on.
        - ``.ANNUNCIATOR_ERROR``: ERR indicator on.
        - ``.ANNUNCIATOR_FILTER``: FILT indicator on.
        - ``.ANNUNCIATOR_LISTEN``: LSTN indicator on.
        - ``.ANNUNCIATOR_MATH``: MATH indicator on.
        - ``.ANNUNCIATOR_REAR``: REAR indicator on.
        - ``.ANNUNCIATOR_REL``: REL indicator on.
        - ``.ANNUNCIATOR_REMOTE``: REM indicator on.
        - ``.ANNUNCIATOR_SAMPLE``: SMPL indicator on.
        - ``.ANNUNCIATOR_SRQ``: SRQ indicator on.
        - ``.ANNUNCIATOR_STAR``: * (asterisk) indicator on.
        - ``.ANNUNCIATOR_TALK``: TALK indicator on.
        - ``.ANNUNCIATOR_TRIGGER``: TRIG indicator on.
        - ``.DIGITS_4_5``: Set the front-panel display resolution to 4.5 digits.
        - ``.DIGITS_5_5``: Set the front-panel display resolution to 5.5 digits.
        - ``.DIGITS_6_5``: Set the front-panel display resolution to 6.5 digits.
        - ``.DISABLE``: Disable the front-panel keys for numeric entry when entering a value.
        - ``.DONT_SAVE``: Do not save code to nonvolatile memory.
        - ``.ENABLE``: Enable the front-panel keys for numeric entry when entering a value.
        - ``.KEY_AUTO``: Represents the range AUTO key.
        - ``.KEY_CONFIG``: Represents the CONFIG key.
        - ``.KEY_DIGITSA``: Represents the DIGITS (display resolution) key.
          For two-channel products, this is the DIGITS key for Channel A.
        - ``.KEY_DIGITSB``: Represents the DIGITS (display resolution) key for Channel B.
        - ``.KEY_DISPLAY``: Represents the DISPLAY key.
        - ``.KEY_ENTER``: Represents the ENTER key.
        - ``.KEY_EXIT``: Represents the EXIT key.
        - ``.KEY_FILTERA``: Represents the FILTER key.
          For two-channel products, this is the FILTER key for Channel A.
        - ``.KEY_FILTERB``: Represents the FILTER key for Channel B.
        - ``.KEY_LEFT``: Represents the left CURSOR key.
        - ``.KEY_LIMITA``: Represents the LIMIT key.
          For two-channel products, this is the LIMIT key for Channel A.
        - ``.KEY_LIMITB``: Represents the LIMIT key.
          For two-channel products, this is the LIMIT key for Channel B.
        - ``.KEY_LOAD``: Represents the LOAD (load test) key.
        - ``.KEY_MEASA``: Represents the MEAS (Measure) key.
          For two-channel products, this is the MEAS key for Channel A.
        - ``.KEY_MEASB``: Represents the MEAS (Measure) key for Channel B.
        - ``.KEY_MENU``: Represents the MENU key.
        - ``.KEY_MODEA``: Represents the MODE (meter mode) key
          For two-channel products, this is the MODE key for Channel A.
        - ``.KEY_MODEB``: Represents the MODE (meter mode) key for Channel B.
        - ``.KEY_NONE``: No key was pressed.
        - ``.KEY_OUTPUTA``: Represents the OUTPUT ON/OFF key.
          For two-channel products, this is the OUTPUT ON/OFF key for Channel A.
        - ``.KEY_OUTPUTB``: Represents the OUTPUT ON/OFF key.
          For two-channel products, this is the OUTPUT ON/OFF key for Channel B.
        - ``.KEY_RANGEDOWN``: Represents the RANGE down key.
        - ``.KEY_RANGEUP``: Represents the RANGE up key.
        - ``.KEY_RECALL``: Represents the RECALL key.
        - ``.KEY_RELA``: Represents the REL key.
          For two-channel products, this is the REL key for Channel A.
        - ``.KEY_RELB``: Represents the REL key for Channel B.
        - ``.KEY_RIGHT``: Represents the right CURSOR key.
        - ``.KEY_RUN``: Represents the RUN key.
        - ``.KEY_SPEEDA``: Represents the SPEED key.
          For two-channel products, this is the SPEED key for Channel A.
        - ``.KEY_SPEEDB``: Represents the SPEED key.
          For two-channel products, this is the SPEED key for Channel B.
        - ``.KEY_SRCA``: Represents the SRC (Source) key.
          For two-channel products, this is the SRC key for Channel A.
        - ``.KEY_SRCB``: Represents the SRC (Source) key for Channel B.
        - ``.KEY_STORE``: Represents the STORE key.
        - ``.KEY_TRIG``: Represents the TRIG key.
        - ``.LIMIT_IV``: Display the primary limit value.
        - ``.LIMIT_P``: Display the power limit value.
        - ``.LOCK``: Unlock the EXIT (LOCAL) key.
        - ``.MEASURE_DCAMPS``: Display the current measurement function.
        - ``.MEASURE_DCVOLTS``: Display the voltage measurement function.
        - ``.MEASURE_OHMS``: Display the resistance measurement function.
        - ``.MEASURE_WATTS``: Display the power measurement function.
        - ``.SAVE``: Save code to nonvolatile memory.
        - ``.SMUA_SMUB``: Displays source-measure screen for SMU A and SMU B.
        - ``.SMUB``: Displays source-measure and compliance screen for SMU B.
        - ``.UNLOCK``: Lock out the EXIT (LOCAL) key.
        - ``.WHEEL_ENTER``: Represents pressing the navigation wheel.
        - ``.WHEEL_LEFT``: Represents turning the Navigation wheel left.
        - ``.WHEEL_RIGHT``: Represents turning the Navigation wheel right.

    Properties and methods:
        - ``.clear()``: The ``display.clear()`` function.
        - ``.getannunciators()``: The ``display.getannunciators()`` function.
        - ``.getcursor()``: The ``display.getcursor()`` function.
        - ``.getlastkey()``: The ``display.getlastkey()`` function.
        - ``.gettext()``: The ``display.gettext()`` function.
        - ``.inputvalue()``: The ``display.inputvalue()`` function.
        - ``.loadmenu``: The ``display.loadmenu`` command tree.
        - ``.locallockout``: The ``display.locallockout`` attribute.
        - ``.menu()``: The ``display.menu()`` function.
        - ``.numpad``: The ``display.numpad`` attribute.
        - ``.prompt()``: The ``display.prompt()`` function.
        - ``.screen``: The ``display.screen`` attribute.
        - ``.sendkey()``: The ``display.sendkey()`` function.
        - ``.setcursor()``: The ``display.setcursor()`` function.
        - ``.settext()``: The ``display.settext()`` function.
        - ``.smu``: The ``display.smuX`` command tree.
        - ``.trigger``: The ``display.trigger`` command tree.
        - ``.waitkey()``: The ``display.waitkey()`` function.
    """

    ANNUNCIATOR_4_WIRE = "display.ANNUNCIATOR_4_WIRE"
    """str: 4W indicator on."""
    ANNUNCIATOR_ARM = "display.ANNUNCIATOR_ARM"
    """str: ARM indicator on."""
    ANNUNCIATOR_AUTO = "display.ANNUNCIATOR_AUTO"
    """str: AUTO indicator on."""
    ANNUNCIATOR_EDIT = "display.ANNUNCIATOR_EDIT"
    """str: EDIT indicator on."""
    ANNUNCIATOR_ERROR = "display.ANNUNCIATOR_ERROR"
    """str: ERR indicator on."""
    ANNUNCIATOR_FILTER = "display.ANNUNCIATOR_FILTER"
    """str: FILT indicator on."""
    ANNUNCIATOR_LISTEN = "display.ANNUNCIATOR_LISTEN"
    """str: LSTN indicator on."""
    ANNUNCIATOR_MATH = "display.ANNUNCIATOR_MATH"
    """str: MATH indicator on."""
    ANNUNCIATOR_REAR = "display.ANNUNCIATOR_REAR"
    """str: REAR indicator on."""
    ANNUNCIATOR_REL = "display.ANNUNCIATOR_REL"
    """str: REL indicator on."""
    ANNUNCIATOR_REMOTE = "display.ANNUNCIATOR_REMOTE"
    """str: REM indicator on."""
    ANNUNCIATOR_SAMPLE = "display.ANNUNCIATOR_SAMPLE"
    """str: SMPL indicator on."""
    ANNUNCIATOR_SRQ = "display.ANNUNCIATOR_SRQ"
    """str: SRQ indicator on."""
    ANNUNCIATOR_STAR = "display.ANNUNCIATOR_STAR"
    """str: * (asterisk) indicator on."""
    ANNUNCIATOR_TALK = "display.ANNUNCIATOR_TALK"
    """str: TALK indicator on."""
    ANNUNCIATOR_TRIGGER = "display.ANNUNCIATOR_TRIGGER"
    """str: TRIG indicator on."""
    DIGITS_4_5 = "display.DIGITS_4_5"
    """str: Set the front-panel display resolution to 4.5 digits."""
    DIGITS_5_5 = "display.DIGITS_5_5"
    """str: Set the front-panel display resolution to 5.5 digits."""
    DIGITS_6_5 = "display.DIGITS_6_5"
    """str: Set the front-panel display resolution to 6.5 digits."""
    DISABLE = "display.DISABLE"
    """str: Disable the front-panel keys for numeric entry when entering a value."""
    DONT_SAVE = "display.DONT_SAVE"
    """str: Do not save code to nonvolatile memory."""
    ENABLE = "display.ENABLE"
    """str: Enable the front-panel keys for numeric entry when entering a value."""
    KEY_AUTO = "display.KEY_AUTO"
    """str: Represents the range AUTO key."""
    KEY_CONFIG = "display.KEY_CONFIG"
    """str: Represents the CONFIG key."""
    KEY_DIGITSA = "display.KEY_DIGITSA"
    """str: Represents the DIGITS (display resolution) key.
For two-channel products, this is the DIGITS key for Channel A."""
    KEY_DIGITSB = "display.KEY_DIGITSB"
    """str: Represents the DIGITS (display resolution) key for Channel B."""
    KEY_DISPLAY = "display.KEY_DISPLAY"
    """str: Represents the DISPLAY key."""
    KEY_ENTER = "display.KEY_ENTER"
    """str: Represents the ENTER key."""
    KEY_EXIT = "display.KEY_EXIT"
    """str: Represents the EXIT key."""
    KEY_FILTERA = "display.KEY_FILTERA"
    """str: Represents the FILTER key.
For two-channel products, this is the FILTER key for Channel A."""
    KEY_FILTERB = "display.KEY_FILTERB"
    """str: Represents the FILTER key for Channel B."""
    KEY_LEFT = "display.KEY_LEFT"
    """str: Represents the left CURSOR key."""
    KEY_LIMITA = "display.KEY_LIMITA"
    """str: Represents the LIMIT key.
For two-channel products, this is the LIMIT key for Channel A."""
    KEY_LIMITB = "display.KEY_LIMITB"
    """str: Represents the LIMIT key.
For two-channel products, this is the LIMIT key for Channel B."""
    KEY_LOAD = "display.KEY_LOAD"
    """str: Represents the LOAD (load test) key."""
    KEY_MEASA = "display.KEY_MEASA"
    """str: Represents the MEAS (Measure) key.
For two-channel products, this is the MEAS key for Channel A."""
    KEY_MEASB = "display.KEY_MEASB"
    """str: Represents the MEAS (Measure) key for Channel B."""
    KEY_MENU = "display.KEY_MENU"
    """str: Represents the MENU key."""
    KEY_MODEA = "display.KEY_MODEA"
    """str: Represents the MODE (meter mode) key
For two-channel products, this is the MODE key for Channel A."""
    KEY_MODEB = "display.KEY_MODEB"
    """str: Represents the MODE (meter mode) key for Channel B."""
    KEY_NONE = "display.KEY_NONE"
    """str: No key was pressed."""
    KEY_OUTPUTA = "display.KEY_OUTPUTA"
    """str: Represents the OUTPUT ON/OFF key.
For two-channel products, this is the OUTPUT ON/OFF key for Channel A."""
    KEY_OUTPUTB = "display.KEY_OUTPUTB"
    """str: Represents the OUTPUT ON/OFF key.
For two-channel products, this is the OUTPUT ON/OFF key for Channel B."""
    KEY_RANGEDOWN = "display.KEY_RANGEDOWN"
    """str: Represents the RANGE down key."""
    KEY_RANGEUP = "display.KEY_RANGEUP"
    """str: Represents the RANGE up key."""
    KEY_RECALL = "display.KEY_RECALL"
    """str: Represents the RECALL key."""
    KEY_RELA = "display.KEY_RELA"
    """str: Represents the REL key.
For two-channel products, this is the REL key for Channel A."""
    KEY_RELB = "display.KEY_RELB"
    """str: Represents the REL key for Channel B."""
    KEY_RIGHT = "display.KEY_RIGHT"
    """str: Represents the right CURSOR key."""
    KEY_RUN = "display.KEY_RUN"
    """str: Represents the RUN key."""
    KEY_SPEEDA = "display.KEY_SPEEDA"
    """str: Represents the SPEED key.
For two-channel products, this is the SPEED key for Channel A."""
    KEY_SPEEDB = "display.KEY_SPEEDB"
    """str: Represents the SPEED key.
For two-channel products, this is the SPEED key for Channel B."""
    KEY_SRCA = "display.KEY_SRCA"
    """str: Represents the SRC (Source) key.
For two-channel products, this is the SRC key for Channel A."""
    KEY_SRCB = "display.KEY_SRCB"
    """str: Represents the SRC (Source) key for Channel B."""
    KEY_STORE = "display.KEY_STORE"
    """str: Represents the STORE key."""
    KEY_TRIG = "display.KEY_TRIG"
    """str: Represents the TRIG key."""
    LIMIT_IV = "display.LIMIT_IV"
    """str: Display the primary limit value."""
    LIMIT_P = "display.LIMIT_P"
    """str: Display the power limit value."""
    LOCK = "display.LOCK"
    """str: Unlock the EXIT (LOCAL) key."""
    MEASURE_DCAMPS = "display.MEASURE_DCAMPS"
    """str: Display the current measurement function."""
    MEASURE_DCVOLTS = "display.MEASURE_DCVOLTS"
    """str: Display the voltage measurement function."""
    MEASURE_OHMS = "display.MEASURE_OHMS"
    """str: Display the resistance measurement function."""
    MEASURE_WATTS = "display.MEASURE_WATTS"
    """str: Display the power measurement function."""
    SAVE = "display.SAVE"
    """str: Save code to nonvolatile memory."""
    SMUA_SMUB = "display.SMUA_SMUB"
    """str: Displays source-measure screen for SMU A and SMU B."""
    SMUB = "display.SMUB"
    """str: Displays source-measure and compliance screen for SMU B."""
    UNLOCK = "display.UNLOCK"
    """str: Lock out the EXIT (LOCAL) key."""
    WHEEL_ENTER = "display.WHEEL_ENTER"
    """str: Represents pressing the navigation wheel."""
    WHEEL_LEFT = "display.WHEEL_LEFT"
    """str: Represents turning the Navigation wheel left."""
    WHEEL_RIGHT = "display.WHEEL_RIGHT"
    """str: Represents turning the Navigation wheel right."""

    def __init__(self, device: Optional["TSPControl"] = None, cmd_syntax: str = "display") -> None:
        super().__init__(device, cmd_syntax)
        self._loadmenu = DisplayLoadmenu(device, f"{self._cmd_syntax}.loadmenu")
        self._smu: Dict[str, DisplaySmuxItem] = DefaultDictPassKeyToFactory(
            lambda x: DisplaySmuxItem(device, f"{self._cmd_syntax}.smu{x}")
        )
        self._trigger = DisplayTrigger(device, f"{self._cmd_syntax}.trigger")

    @property
    def loadmenu(self) -> DisplayLoadmenu:
        """Return the ``display.loadmenu`` command tree.

        Sub-properties and sub-methods:
            - ``.add()``: The ``display.loadmenu.add()`` function.
            - ``.delete()``: The ``display.loadmenu.delete()`` function.
        """
        return self._loadmenu

    @property
    def locallockout(self) -> str:
        """Access the ``display.locallockout`` attribute.

        Description:
            - This attribute describes whether or not the EXIT (LOCAL) key on the instrument front
              panel is enabled.

        Usage:
            - Accessing this property will send the ``print(display.locallockout)`` query.
            - Setting this property to a value will send the ``display.locallockout = value``
              command.

        TSP Syntax:
            ```
            - display.locallockout = value
            - print(display.locallockout)
            ```

        Info:
            - ``lockout``, the 0 or display.UNLOCK: Unlocks EXIT (LOCAL) key
              1 or display.LOCK: Locks out EXIT (LOCAL) key.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".locallockout"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.locallockout)"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to access the ``{self._cmd_syntax}.locallockout`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @locallockout.setter
    def locallockout(self, value: Union[str, float]) -> None:
        """Access the ``display.locallockout`` attribute.

        Description:
            - This attribute describes whether or not the EXIT (LOCAL) key on the instrument front
              panel is enabled.

        Usage:
            - Accessing this property will send the ``print(display.locallockout)`` query.
            - Setting this property to a value will send the ``display.locallockout = value``
              command.

        TSP Syntax:
            ```
            - display.locallockout = value
            - print(display.locallockout)
            ```

        Info:
            - ``lockout``, the 0 or display.UNLOCK: Unlocks EXIT (LOCAL) key
              1 or display.LOCK: Locks out EXIT (LOCAL) key.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".locallockout", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.locallockout = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to access the ``{self._cmd_syntax}.locallockout`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def numpad(self) -> str:
        """Access the ``display.numpad`` attribute.

        Description:
            - This attribute controls whether the front panel keys act as a numeric keypad during
              value entry.

        Usage:
            - Accessing this property will send the ``print(display.numpad)`` query.
            - Setting this property to a value will send the ``display.numpad = value`` command.

        TSP Syntax:
            ```
            - display.numpad = value
            - print(display.numpad)
            ```

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".numpad"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.numpad)"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to access the ``{self._cmd_syntax}.numpad`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @numpad.setter
    def numpad(self, value: Union[str, float]) -> None:
        """Access the ``display.numpad`` attribute.

        Description:
            - This attribute controls whether the front panel keys act as a numeric keypad during
              value entry.

        Usage:
            - Accessing this property will send the ``print(display.numpad)`` query.
            - Setting this property to a value will send the ``display.numpad = value`` command.

        TSP Syntax:
            ```
            - display.numpad = value
            - print(display.numpad)
            ```

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".numpad", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.numpad = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to access the ``{self._cmd_syntax}.numpad`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def screen(self) -> str:
        """Access the ``display.screen`` attribute.

        Description:
            - This attribute contains the selected display screen.

        Usage:
            - Accessing this property will send the ``print(display.screen)`` query.
            - Setting this property to a value will send the ``display.screen = value`` command.

        TSP Syntax:
            ```
            - display.screen = value
            - print(display.screen)
            ```

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".screen"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.screen)"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to access the ``{self._cmd_syntax}.screen`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @screen.setter
    def screen(self, value: Union[str, float]) -> None:
        """Access the ``display.screen`` attribute.

        Description:
            - This attribute contains the selected display screen.

        Usage:
            - Accessing this property will send the ``print(display.screen)`` query.
            - Setting this property to a value will send the ``display.screen = value`` command.

        TSP Syntax:
            ```
            - display.screen = value
            - print(display.screen)
            ```

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".screen", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.screen = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to access the ``{self._cmd_syntax}.screen`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @property
    def smu(self) -> Dict[str, DisplaySmuxItem]:
        """Return the ``display.smuX`` command tree.

        Info:
            - ``X``, the source-measure unit (SMU) channel (for example, display.smua.digits applies
              to SMU channel A).

        Sub-properties and sub-methods:
            - ``.digits``: The ``display.smuX.digits`` attribute.
            - ``.limit``: The ``display.smuX.limit`` command tree.
            - ``.measure``: The ``display.smuX.measure`` command tree.
        """
        return self._smu

    @property
    def trigger(self) -> DisplayTrigger:
        """Return the ``display.trigger`` command tree.

        Constants:
            - ``.EVENT_ID``: The event ID of the event generated when the front-panel TRIG key is
              pressed.

        Sub-properties and sub-methods:
            - ``.clear()``: The ``display.trigger.clear()`` function.
            - ``.overrun``: The ``display.trigger.overrun`` attribute.
            - ``.wait()``: The ``display.trigger.wait()`` function.
        """
        return self._trigger

    def clear(self) -> None:
        """Run the ``display.clear()`` function.

        Description:
            - This function clears all lines of the front-panel display.

        TSP Syntax:
            ```
            - display.clear()
            ```

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(  # type: ignore[union-attr]
                f"{self._cmd_syntax}.clear()"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.clear()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def getannunciators(self) -> str:
        """Run the ``display.getannunciators()`` function.

        Description:
            - This function reads the annunciators (indicators) that are presently turned on.

        TSP Syntax:
            ```
            - display.getannunciators()
            ```

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.getannunciators())"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.getannunciators()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def getcursor(self) -> str:
        """Run the ``display.getcursor()`` function.

        Description:
            - This function reads the present position of the cursor on the front-panel display.

        TSP Syntax:
            ```
            - display.getcursor()
            ```

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.getcursor())"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.getcursor()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def getlastkey(self) -> str:
        """Run the ``display.getlastkey()`` function.

        Description:
            - This function retrieves the key code for the last pressed key.

        TSP Syntax:
            ```
            - display.getlastkey()
            ```

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.getlastkey())"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.getlastkey()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def gettext(
        self,
        embellished: Optional[str] = None,
        row: Optional[str] = None,
        column_start: Optional[str] = None,
        column_end: Optional[int] = None,
    ) -> str:
        """Run the ``display.gettext()`` function.

        Description:
            - This function reads the text displayed on the front panel.

        TSP Syntax:
            ```
            - display.gettext()
            ```

        Args:
            embellished (optional): Indicates type of returned text.
            row (optional): Selects the row from which to read the text.
            column_start (optional): Selects the first column from which to read text; for row 1,
                the valid column numbers are 1 to 20; for row 2, the valid column numbers are 1 to
                32; if nothing is selected, 1 is used.
            column_end (optional): Selects the last column from which to read text; for row 1, the
                valid column numbers are 1 to 20; for row 2, the valid column numbers are 1 to 32;
                the default is 20 for row 1, and 32 for row 2.

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            function_args = ", ".join(
                str(x)
                for x in (
                    embellished,
                    row,
                    column_start,
                    column_end,
                )
                if x is not None
            )
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.gettext({function_args}))"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.gettext()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def inputvalue(
        self,
        format_: str,
        default: Optional[str] = None,
        minimum: Optional[str] = None,
        maximum: Optional[str] = None,
    ) -> None:
        """Run the ``display.inputvalue()`` function.

        Description:
            - This function displays a formatted input field on the front-panel display that the
              operator can edit.

        TSP Syntax:
            ```
            - display.inputvalue()
            ```

        Args:
            format_: A string that defines how the input field is formatted; see Details for more
                information.
            default (optional): The default value for the input value.
            minimum (optional): The minimum input value.
            maximum (optional): The maximum input value.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            function_args = ", ".join(
                str(x)
                for x in (
                    f'"{format_}"',
                    default,
                    minimum,
                    maximum,
                )
                if x is not None
            )
            self._device.write(  # type: ignore[union-attr]
                f"{self._cmd_syntax}.inputvalue({function_args})"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.inputvalue()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def menu(self, name: str, items: str) -> str:
        """Run the ``display.menu()`` function.

        Description:
            - This function presents a menu on the front-panel display.

        TSP Syntax:
            ```
            - display.menu()
            ```

        Args:
            name: Menu name to display on the top line.
            items: Menu items to display on the bottom line.

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f'print({self._cmd_syntax}.menu("{name}", "{items}"))'
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.menu()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def prompt(
        self,
        format_: str,
        units: str,
        help_: str,
        default: Optional[str] = None,
        minimum: Optional[str] = None,
        maximum: Optional[str] = None,
    ) -> None:
        """Run the ``display.prompt()`` function.

        Description:
            - This function prompts the user to enter a parameter from the front panel of the
              instrument.

        TSP Syntax:
            ```
            - display.prompt()
            ```

        Args:
            format_: A string that defines how the input field is formatted; see Details for more
                information.
            units: Set the units text string for the top line (eight characters maximum); this
                indicates the units (for example, 'V' or 'A') for the value.
            help_: Text string to display on the bottom line (32 characters maximum).
            default (optional): The value that is shown when the value is first displayed.
            minimum (optional): The minimum input value that can be entered.
            maximum (optional): The maximum input value that can be entered (must be more than
                minimum).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            function_args = ", ".join(
                str(x)
                for x in (
                    f'"{format_}"',
                    f'"{units}"',
                    f'"{help_}"',
                    default,
                    minimum,
                    maximum,
                )
                if x is not None
            )
            self._device.write(  # type: ignore[union-attr]
                f"{self._cmd_syntax}.prompt({function_args})"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.prompt()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def sendkey(self, key_code: str) -> None:
        """Run the ``display.sendkey()`` function.

        Description:
            - This function sends a code that simulates the action of a front-panel control.

        TSP Syntax:
            ```
            - display.sendkey()
            ```

        Args:
            key_code: A parameter that specifies the key press to simulate; see Details for more
                information.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(  # type: ignore[union-attr]
                f"{self._cmd_syntax}.sendkey({key_code})"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.sendkey()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def setcursor(self, row: str, column: str, style: Optional[str] = None) -> None:
        """Run the ``display.setcursor()`` function.

        Description:
            - This function sets the position of the cursor.

        TSP Syntax:
            ```
            - display.setcursor()
            ```

        Args:
            row: The row number for the cursor (1 or 2).
            column: The active column position to set; row 1 has columns 1 to 20, row 2 has columns
                1 to 32.
            style (optional): Set the cursor to invisible (0, default) or blinking (1).

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            function_args = ", ".join(
                str(x)
                for x in (
                    row,
                    column,
                    style,
                )
                if x is not None
            )
            self._device.write(  # type: ignore[union-attr]
                f"{self._cmd_syntax}.setcursor({function_args})"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.setcursor()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def settext(self, text: str) -> None:
        """Run the ``display.settext()`` function.

        Description:
            - This function displays text on the front-panel user screen.

        TSP Syntax:
            ```
            - display.settext()
            ```

        Args:
            text: Text message to be displayed, with optional character codes.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(  # type: ignore[union-attr]
                f'{self._cmd_syntax}.settext("{text}")'
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.settext()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def waitkey(self) -> str:
        """Run the ``display.waitkey()`` function.

        Description:
            - This function captures the key code value for the next front-panel action.

        TSP Syntax:
            ```
            - display.waitkey()
            ```

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.waitkey())"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.waitkey()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error



"""The filtervu commands module.

These commands are used in the following models:
DPO2K, DPO2KB, MSO2K, MSO2KB

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:
    ```
    - FILTERVu:FREQuency <NR3>
    - FILTERVu:FREQuency:AVAILable?
    - FILTERVu:FREQuency?
    ```
"""

from typing import Optional, TYPE_CHECKING

from ..helpers import SCPICmdRead, SCPICmdWrite

if TYPE_CHECKING:
    from tm_devices.driver_mixins.device_control.pi_control import PIControl


class FiltervuFrequencyAvailable(SCPICmdRead):
    """The ``FILTERVu:FREQuency:AVAILable`` command.

    Description:
        - Returns a comma separated list of filter frequencies available based on the current
          instrument settings. The source waveform (as specified by the ``DATA:SOURCE``) must be
          turned on for this query to generate a response.

    Usage:
        - Using the ``.query()`` method will send the ``FILTERVu:FREQuency:AVAILable?`` query.
        - Using the ``.verify(value)`` method will send the ``FILTERVu:FREQuency:AVAILable?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - FILTERVu:FREQuency:AVAILable?
        ```
    """


class FiltervuFrequency(SCPICmdWrite, SCPICmdRead):
    """The ``FILTERVu:FREQuency`` command.

    Description:
        - Sets or queries the FilterVu frequency to the closest value supported with the current
          acquisition settings.

    Usage:
        - Using the ``.query()`` method will send the ``FILTERVu:FREQuency?`` query.
        - Using the ``.verify(value)`` method will send the ``FILTERVu:FREQuency?`` query and raise
          an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``FILTERVu:FREQuency value`` command.

    SCPI Syntax:
        ```
        - FILTERVu:FREQuency <NR3>
        - FILTERVu:FREQuency?
        ```

    Info:
        - ``<NR3>`` is the integer format for the current FilterVu frequency setting.

    Properties:
        - ``.available``: The ``FILTERVu:FREQuency:AVAILable`` command.
    """

    def __init__(self, device: Optional["PIControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._available = FiltervuFrequencyAvailable(device, f"{self._cmd_syntax}:AVAILable")

    @property
    def available(self) -> FiltervuFrequencyAvailable:
        """Return the ``FILTERVu:FREQuency:AVAILable`` command.

        Description:
            - Returns a comma separated list of filter frequencies available based on the current
              instrument settings. The source waveform (as specified by the ``DATA:SOURCE``) must be
              turned on for this query to generate a response.

        Usage:
            - Using the ``.query()`` method will send the ``FILTERVu:FREQuency:AVAILable?`` query.
            - Using the ``.verify(value)`` method will send the ``FILTERVu:FREQuency:AVAILable?``
              query and raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - FILTERVu:FREQuency:AVAILable?
            ```
        """
        return self._available


class Filtervu(SCPICmdRead):
    """The ``FILTERVu`` command tree.

    Usage:
        - Using the ``.query()`` method will send the ``FILTERVu?`` query.
        - Using the ``.verify(value)`` method will send the ``FILTERVu?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.frequency``: The ``FILTERVu:FREQuency`` command.
    """

    def __init__(self, device: Optional["PIControl"] = None, cmd_syntax: str = "FILTERVu") -> None:
        super().__init__(device, cmd_syntax)
        self._frequency = FiltervuFrequency(device, f"{self._cmd_syntax}:FREQuency")

    @property
    def frequency(self) -> FiltervuFrequency:
        """Return the ``FILTERVu:FREQuency`` command.

        Description:
            - Sets or queries the FilterVu frequency to the closest value supported with the current
              acquisition settings.

        Usage:
            - Using the ``.query()`` method will send the ``FILTERVu:FREQuency?`` query.
            - Using the ``.verify(value)`` method will send the ``FILTERVu:FREQuency?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``FILTERVu:FREQuency value`` command.

        SCPI Syntax:
            ```
            - FILTERVu:FREQuency <NR3>
            - FILTERVu:FREQuency?
            ```

        Info:
            - ``<NR3>`` is the integer format for the current FilterVu frequency setting.

        Sub-properties:
            - ``.available``: The ``FILTERVu:FREQuency:AVAILable`` command.
        """
        return self._frequency



# pylint: disable=line-too-long
"""The cplayback commands module.

These commands are used in the following models:
AWG70KA, AWG70KB

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:
    ```
    - CPLayback:CAPTure:FILE <signal_name>,{SIQ|CIQ},<file_path>[,<file_path>]
    - CPLayback:CAPTure:INSTrument:OSCilloscope <signal_name>,<instrument_name>,<source_1>,<source_2>
    - CPLayback:CAPTure:INSTrument:RSA <signal_name>,<instrument_name>
    - CPLayback:CAPTure:WLISt <signal_name>,<waveform_name>
    - CPLayback:CLISt:NAME? <index>
    - CPLayback:CLISt:SIGNal:DELete {ALL|signal_name}
    - CPLayback:CLISt:SIGNal:SCOMpile <signal_name>,{OFF|ON|1|0}
    - CPLayback:CLISt:SIGNal:SCOMpile?
    - CPLayback:CLISt:SIGNal:WAVeform:FOFFset <signal_name>,<ALL|NR1>,<NRf>
    - CPLayback:CLISt:SIGNal:WAVeform:FOFFset? <signal_name>,<NR1>
    - CPLayback:CLISt:SIGNal:WAVeform:NAME? <signal_name>,<NR1>
    - CPLayback:CLISt:SIGNal:WAVeform:OTIMe <signal_name>,<ALL|<NR1>,<NRf>
    - CPLayback:CLISt:SIGNal:WAVeform:OTIMe? <signal_name>,<NR1>
    - CPLayback:CLISt:SIGNal:WAVeform:SRATe <signal_name>,<ALL|NR1>,<NRf>
    - CPLayback:CLISt:SIGNal:WAVeform:SRATe? <signal_name>,<NR1>
    - CPLayback:CLISt:SIGNal:WCOunt? <signal_name>
    - CPLayback:CLISt:SIZE?
    - CPLayback:COMPile
    - CPLayback:COMPile:CFRequency <carrier_frequency>
    - CPLayback:COMPile:CFRequency?
    - CPLayback:COMPile:LSEQuence {ON|OFF|1|0}
    - CPLayback:COMPile:LSEQuence?
    - CPLayback:COMPile:NORMalize {NONE|FSCale|ZREFerence}
    - CPLayback:COMPile:NORMalize?
    - CPLayback:COMPile:SRATe <NRf>
    - CPLayback:COMPile:SRATe:AUTO {ON|OFF|1|0}
    - CPLayback:COMPile:SRATe:AUTO?
    - CPLayback:COMPile:SRATe?
    ```
"""  # noqa: E501

from typing import Optional, TYPE_CHECKING

from ..helpers import SCPICmdRead, SCPICmdReadWithArguments, SCPICmdWrite, SCPICmdWriteNoArguments

if TYPE_CHECKING:
    from tm_devices.driver_mixins.device_control.pi_control import PIControl


class CplaybackCompileSrateAuto(SCPICmdWrite, SCPICmdRead):
    """The ``CPLayback:COMPile:SRATe:AUTO`` command.

    Description:
        - This command sets or returns if the system will calculate the output sampling rate
          automatically when compiling the selected signals.

    Usage:
        - Using the ``.query()`` method will send the ``CPLayback:COMPile:SRATe:AUTO?`` query.
        - Using the ``.verify(value)`` method will send the ``CPLayback:COMPile:SRATe:AUTO?`` query
          and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``CPLayback:COMPile:SRATe:AUTO value``
          command.

    SCPI Syntax:
        ```
        - CPLayback:COMPile:SRATe:AUTO {ON|OFF|1|0}
        - CPLayback:COMPile:SRATe:AUTO?
        ```
    """


class CplaybackCompileSrate(SCPICmdWrite, SCPICmdRead):
    """The ``CPLayback:COMPile:SRATe`` command.

    Description:
        - This command sets or returns the output sampling rate for the compiled signals.

    Usage:
        - Using the ``.query()`` method will send the ``CPLayback:COMPile:SRATe?`` query.
        - Using the ``.verify(value)`` method will send the ``CPLayback:COMPile:SRATe?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``CPLayback:COMPile:SRATe value``
          command.

    SCPI Syntax:
        ```
        - CPLayback:COMPile:SRATe <NRf>
        - CPLayback:COMPile:SRATe?
        ```

    Info:
        - ``*RST`` sets this to the maximum sample rate.

    Properties:
        - ``.auto``: The ``CPLayback:COMPile:SRATe:AUTO`` command.
    """

    def __init__(self, device: Optional["PIControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._auto = CplaybackCompileSrateAuto(device, f"{self._cmd_syntax}:AUTO")

    @property
    def auto(self) -> CplaybackCompileSrateAuto:
        """Return the ``CPLayback:COMPile:SRATe:AUTO`` command.

        Description:
            - This command sets or returns if the system will calculate the output sampling rate
              automatically when compiling the selected signals.

        Usage:
            - Using the ``.query()`` method will send the ``CPLayback:COMPile:SRATe:AUTO?`` query.
            - Using the ``.verify(value)`` method will send the ``CPLayback:COMPile:SRATe:AUTO?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the
              ``CPLayback:COMPile:SRATe:AUTO value`` command.

        SCPI Syntax:
            ```
            - CPLayback:COMPile:SRATe:AUTO {ON|OFF|1|0}
            - CPLayback:COMPile:SRATe:AUTO?
            ```
        """
        return self._auto


class CplaybackCompileNormalize(SCPICmdWrite, SCPICmdRead):
    """The ``CPLayback:COMPile:NORMalize`` command.

    Description:
        - This command sets or returns if the IQ waveforms will be normalized during import.

    Usage:
        - Using the ``.query()`` method will send the ``CPLayback:COMPile:NORMalize?`` query.
        - Using the ``.verify(value)`` method will send the ``CPLayback:COMPile:NORMalize?`` query
          and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``CPLayback:COMPile:NORMalize value``
          command.

    SCPI Syntax:
        ```
        - CPLayback:COMPile:NORMalize {NONE|FSCale|ZREFerence}
        - CPLayback:COMPile:NORMalize?
        ```
    """


class CplaybackCompileLsequence(SCPICmdWrite, SCPICmdRead):
    """The ``CPLayback:COMPile:LSEQuence`` command.

    Description:
        - This command sets or returns if the compiled sequence should loop on itself, setting the
          GoTo of last sequence step to First.

    Usage:
        - Using the ``.query()`` method will send the ``CPLayback:COMPile:LSEQuence?`` query.
        - Using the ``.verify(value)`` method will send the ``CPLayback:COMPile:LSEQuence?`` query
          and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``CPLayback:COMPile:LSEQuence value``
          command.

    SCPI Syntax:
        ```
        - CPLayback:COMPile:LSEQuence {ON|OFF|1|0}
        - CPLayback:COMPile:LSEQuence?
        ```
    """


class CplaybackCompileCfrequency(SCPICmdWrite, SCPICmdRead):
    """The ``CPLayback:COMPile:CFRequency`` command.

    Description:
        - This command sets or returns the Carrier Frequency for the compiled signals.

    Usage:
        - Using the ``.query()`` method will send the ``CPLayback:COMPile:CFRequency?`` query.
        - Using the ``.verify(value)`` method will send the ``CPLayback:COMPile:CFRequency?`` query
          and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``CPLayback:COMPile:CFRequency value``
          command.

    SCPI Syntax:
        ```
        - CPLayback:COMPile:CFRequency <carrier_frequency>
        - CPLayback:COMPile:CFRequency?
        ```

    Info:
        - ``*RST`` sets this to 1 GHz.
    """


class CplaybackCompile(SCPICmdWriteNoArguments, SCPICmdRead):
    """The ``CPLayback:COMPile`` command.

    Description:
        - The command resamples and upconverts the selected signal to the specified carrier
          frequency. With Option 03 (Sequencing) enabled: A sequence is generated containing all
          waveform segments in the signal (even if the signal contains only one waveform segment.
          Without Option 03 (Sequencing): A waveform is generated if there is only one waveform
          segment in the signal. If the signal contains multiple waveform segments, the compile
          fails and an error message is generated. You can select to compile more than one signal at
          a time. The compile process generates a sequence (or waveform) for each of the selected
          signals.

    Usage:
        - Using the ``.write()`` method will send the ``CPLayback:COMPile`` command.

    SCPI Syntax:
        ```
        - CPLayback:COMPile
        ```

    Properties:
        - ``.cfrequency``: The ``CPLayback:COMPile:CFRequency`` command.
        - ``.lsequence``: The ``CPLayback:COMPile:LSEQuence`` command.
        - ``.normalize``: The ``CPLayback:COMPile:NORMalize`` command.
        - ``.srate``: The ``CPLayback:COMPile:SRATe`` command.
    """

    def __init__(self, device: Optional["PIControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._cfrequency = CplaybackCompileCfrequency(device, f"{self._cmd_syntax}:CFRequency")
        self._lsequence = CplaybackCompileLsequence(device, f"{self._cmd_syntax}:LSEQuence")
        self._normalize = CplaybackCompileNormalize(device, f"{self._cmd_syntax}:NORMalize")
        self._srate = CplaybackCompileSrate(device, f"{self._cmd_syntax}:SRATe")

    @property
    def cfrequency(self) -> CplaybackCompileCfrequency:
        """Return the ``CPLayback:COMPile:CFRequency`` command.

        Description:
            - This command sets or returns the Carrier Frequency for the compiled signals.

        Usage:
            - Using the ``.query()`` method will send the ``CPLayback:COMPile:CFRequency?`` query.
            - Using the ``.verify(value)`` method will send the ``CPLayback:COMPile:CFRequency?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the
              ``CPLayback:COMPile:CFRequency value`` command.

        SCPI Syntax:
            ```
            - CPLayback:COMPile:CFRequency <carrier_frequency>
            - CPLayback:COMPile:CFRequency?
            ```

        Info:
            - ``*RST`` sets this to 1 GHz.
        """
        return self._cfrequency

    @property
    def lsequence(self) -> CplaybackCompileLsequence:
        """Return the ``CPLayback:COMPile:LSEQuence`` command.

        Description:
            - This command sets or returns if the compiled sequence should loop on itself, setting
              the GoTo of last sequence step to First.

        Usage:
            - Using the ``.query()`` method will send the ``CPLayback:COMPile:LSEQuence?`` query.
            - Using the ``.verify(value)`` method will send the ``CPLayback:COMPile:LSEQuence?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``CPLayback:COMPile:LSEQuence value``
              command.

        SCPI Syntax:
            ```
            - CPLayback:COMPile:LSEQuence {ON|OFF|1|0}
            - CPLayback:COMPile:LSEQuence?
            ```
        """
        return self._lsequence

    @property
    def normalize(self) -> CplaybackCompileNormalize:
        """Return the ``CPLayback:COMPile:NORMalize`` command.

        Description:
            - This command sets or returns if the IQ waveforms will be normalized during import.

        Usage:
            - Using the ``.query()`` method will send the ``CPLayback:COMPile:NORMalize?`` query.
            - Using the ``.verify(value)`` method will send the ``CPLayback:COMPile:NORMalize?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``CPLayback:COMPile:NORMalize value``
              command.

        SCPI Syntax:
            ```
            - CPLayback:COMPile:NORMalize {NONE|FSCale|ZREFerence}
            - CPLayback:COMPile:NORMalize?
            ```
        """
        return self._normalize

    @property
    def srate(self) -> CplaybackCompileSrate:
        """Return the ``CPLayback:COMPile:SRATe`` command.

        Description:
            - This command sets or returns the output sampling rate for the compiled signals.

        Usage:
            - Using the ``.query()`` method will send the ``CPLayback:COMPile:SRATe?`` query.
            - Using the ``.verify(value)`` method will send the ``CPLayback:COMPile:SRATe?`` query
              and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``CPLayback:COMPile:SRATe value``
              command.

        SCPI Syntax:
            ```
            - CPLayback:COMPile:SRATe <NRf>
            - CPLayback:COMPile:SRATe?
            ```

        Info:
            - ``*RST`` sets this to the maximum sample rate.

        Sub-properties:
            - ``.auto``: The ``CPLayback:COMPile:SRATe:AUTO`` command.
        """
        return self._srate


class CplaybackClistSize(SCPICmdRead):
    """The ``CPLayback:CLISt:SIZE`` command.

    Description:
        - This command returns the number of signals in the Captured Signal List.

    Usage:
        - Using the ``.query()`` method will send the ``CPLayback:CLISt:SIZE?`` query.
        - Using the ``.verify(value)`` method will send the ``CPLayback:CLISt:SIZE?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - CPLayback:CLISt:SIZE?
        ```
    """


class CplaybackClistSignalWcount(SCPICmdReadWithArguments):
    """The ``CPLayback:CLISt:SIGNal:WCOunt`` command.

    Description:
        - This command returns the number of waveform segments in the specified signal in the
          Captured Signal List.

    Usage:
        - Using the ``.query(argument)`` method will send the
          ``CPLayback:CLISt:SIGNal:WCOunt? argument`` query.
        - Using the ``.verify(argument, value)`` method will send the
          ``CPLayback:CLISt:SIGNal:WCOunt? argument`` query and raise an AssertionError if the
          returned value does not match ``value``.

    SCPI Syntax:
        ```
        - CPLayback:CLISt:SIGNal:WCOunt? <signal_name>
        ```
    """


class CplaybackClistSignalWaveformSrate(SCPICmdWrite, SCPICmdReadWithArguments):
    """The ``CPLayback:CLISt:SIGNal:WAVeform:SRATe`` command.

    Description:
        - This command sets or returns the baseband sample rate of a waveform segment of a signal in
          the Captured Signal List.

    Usage:
        - Using the ``.query(argument)`` method will send the
          ``CPLayback:CLISt:SIGNal:WAVeform:SRATe? argument`` query.
        - Using the ``.verify(argument, value)`` method will send the
          ``CPLayback:CLISt:SIGNal:WAVeform:SRATe? argument`` query and raise an AssertionError if
          the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the
          ``CPLayback:CLISt:SIGNal:WAVeform:SRATe value`` command.

    SCPI Syntax:
        ```
        - CPLayback:CLISt:SIGNal:WAVeform:SRATe <signal_name>,<ALL|NR1>,<NRf>
        - CPLayback:CLISt:SIGNal:WAVeform:SRATe? <signal_name>,<NR1>
        ```
    """


class CplaybackClistSignalWaveformOtime(SCPICmdWrite, SCPICmdReadWithArguments):
    """The ``CPLayback:CLISt:SIGNal:WAVeform:OTIMe`` command.

    Description:
        - This command sets or returns the Off time between waveform segments of the specified
          signal in the Captured Signal List.

    Usage:
        - Using the ``.query(argument)`` method will send the
          ``CPLayback:CLISt:SIGNal:WAVeform:OTIMe? argument`` query.
        - Using the ``.verify(argument, value)`` method will send the
          ``CPLayback:CLISt:SIGNal:WAVeform:OTIMe? argument`` query and raise an AssertionError if
          the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the
          ``CPLayback:CLISt:SIGNal:WAVeform:OTIMe value`` command.

    SCPI Syntax:
        ```
        - CPLayback:CLISt:SIGNal:WAVeform:OTIMe <signal_name>,<ALL|<NR1>,<NRf>
        - CPLayback:CLISt:SIGNal:WAVeform:OTIMe? <signal_name>,<NR1>
        ```
    """


class CplaybackClistSignalWaveformName(SCPICmdReadWithArguments):
    """The ``CPLayback:CLISt:SIGNal:WAVeform:NAME`` command.

    Description:
        - This command returns the name of the specified waveform segment of the specified signal in
          the Captured Signal List.

    Usage:
        - Using the ``.query(argument)`` method will send the
          ``CPLayback:CLISt:SIGNal:WAVeform:NAME? argument`` query.
        - Using the ``.verify(argument, value)`` method will send the
          ``CPLayback:CLISt:SIGNal:WAVeform:NAME? argument`` query and raise an AssertionError if
          the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - CPLayback:CLISt:SIGNal:WAVeform:NAME? <signal_name>,<NR1>
        ```
    """


class CplaybackClistSignalWaveformFoffset(SCPICmdWrite, SCPICmdReadWithArguments):
    """The ``CPLayback:CLISt:SIGNal:WAVeform:FOFFset`` command.

    Description:
        - This command sets or returns the frequency offset of the specified waveform segment of the
          specified signal in the Captured Signal List.

    Usage:
        - Using the ``.query(argument)`` method will send the
          ``CPLayback:CLISt:SIGNal:WAVeform:FOFFset? argument`` query.
        - Using the ``.verify(argument, value)`` method will send the
          ``CPLayback:CLISt:SIGNal:WAVeform:FOFFset? argument`` query and raise an AssertionError if
          the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the
          ``CPLayback:CLISt:SIGNal:WAVeform:FOFFset value`` command.

    SCPI Syntax:
        ```
        - CPLayback:CLISt:SIGNal:WAVeform:FOFFset <signal_name>,<ALL|NR1>,<NRf>
        - CPLayback:CLISt:SIGNal:WAVeform:FOFFset? <signal_name>,<NR1>
        ```
    """


class CplaybackClistSignalWaveform(SCPICmdRead):
    """The ``CPLayback:CLISt:SIGNal:WAVeform`` command tree.

    Usage:
        - Using the ``.query()`` method will send the ``CPLayback:CLISt:SIGNal:WAVeform?`` query.
        - Using the ``.verify(value)`` method will send the ``CPLayback:CLISt:SIGNal:WAVeform?``
          query and raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.foffset``: The ``CPLayback:CLISt:SIGNal:WAVeform:FOFFset`` command.
        - ``.name``: The ``CPLayback:CLISt:SIGNal:WAVeform:NAME`` command.
        - ``.otime``: The ``CPLayback:CLISt:SIGNal:WAVeform:OTIMe`` command.
        - ``.srate``: The ``CPLayback:CLISt:SIGNal:WAVeform:SRATe`` command.
    """

    def __init__(self, device: Optional["PIControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._foffset = CplaybackClistSignalWaveformFoffset(device, f"{self._cmd_syntax}:FOFFset")
        self._name = CplaybackClistSignalWaveformName(device, f"{self._cmd_syntax}:NAME")
        self._otime = CplaybackClistSignalWaveformOtime(device, f"{self._cmd_syntax}:OTIMe")
        self._srate = CplaybackClistSignalWaveformSrate(device, f"{self._cmd_syntax}:SRATe")

    @property
    def foffset(self) -> CplaybackClistSignalWaveformFoffset:
        """Return the ``CPLayback:CLISt:SIGNal:WAVeform:FOFFset`` command.

        Description:
            - This command sets or returns the frequency offset of the specified waveform segment of
              the specified signal in the Captured Signal List.

        Usage:
            - Using the ``.query(argument)`` method will send the
              ``CPLayback:CLISt:SIGNal:WAVeform:FOFFset? argument`` query.
            - Using the ``.verify(argument, value)`` method will send the
              ``CPLayback:CLISt:SIGNal:WAVeform:FOFFset? argument`` query and raise an
              AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the
              ``CPLayback:CLISt:SIGNal:WAVeform:FOFFset value`` command.

        SCPI Syntax:
            ```
            - CPLayback:CLISt:SIGNal:WAVeform:FOFFset <signal_name>,<ALL|NR1>,<NRf>
            - CPLayback:CLISt:SIGNal:WAVeform:FOFFset? <signal_name>,<NR1>
            ```
        """
        return self._foffset

    @property
    def name(self) -> CplaybackClistSignalWaveformName:
        """Return the ``CPLayback:CLISt:SIGNal:WAVeform:NAME`` command.

        Description:
            - This command returns the name of the specified waveform segment of the specified
              signal in the Captured Signal List.

        Usage:
            - Using the ``.query(argument)`` method will send the
              ``CPLayback:CLISt:SIGNal:WAVeform:NAME? argument`` query.
            - Using the ``.verify(argument, value)`` method will send the
              ``CPLayback:CLISt:SIGNal:WAVeform:NAME? argument`` query and raise an AssertionError
              if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - CPLayback:CLISt:SIGNal:WAVeform:NAME? <signal_name>,<NR1>
            ```
        """
        return self._name

    @property
    def otime(self) -> CplaybackClistSignalWaveformOtime:
        """Return the ``CPLayback:CLISt:SIGNal:WAVeform:OTIMe`` command.

        Description:
            - This command sets or returns the Off time between waveform segments of the specified
              signal in the Captured Signal List.

        Usage:
            - Using the ``.query(argument)`` method will send the
              ``CPLayback:CLISt:SIGNal:WAVeform:OTIMe? argument`` query.
            - Using the ``.verify(argument, value)`` method will send the
              ``CPLayback:CLISt:SIGNal:WAVeform:OTIMe? argument`` query and raise an AssertionError
              if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the
              ``CPLayback:CLISt:SIGNal:WAVeform:OTIMe value`` command.

        SCPI Syntax:
            ```
            - CPLayback:CLISt:SIGNal:WAVeform:OTIMe <signal_name>,<ALL|<NR1>,<NRf>
            - CPLayback:CLISt:SIGNal:WAVeform:OTIMe? <signal_name>,<NR1>
            ```
        """
        return self._otime

    @property
    def srate(self) -> CplaybackClistSignalWaveformSrate:
        """Return the ``CPLayback:CLISt:SIGNal:WAVeform:SRATe`` command.

        Description:
            - This command sets or returns the baseband sample rate of a waveform segment of a
              signal in the Captured Signal List.

        Usage:
            - Using the ``.query(argument)`` method will send the
              ``CPLayback:CLISt:SIGNal:WAVeform:SRATe? argument`` query.
            - Using the ``.verify(argument, value)`` method will send the
              ``CPLayback:CLISt:SIGNal:WAVeform:SRATe? argument`` query and raise an AssertionError
              if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the
              ``CPLayback:CLISt:SIGNal:WAVeform:SRATe value`` command.

        SCPI Syntax:
            ```
            - CPLayback:CLISt:SIGNal:WAVeform:SRATe <signal_name>,<ALL|NR1>,<NRf>
            - CPLayback:CLISt:SIGNal:WAVeform:SRATe? <signal_name>,<NR1>
            ```
        """
        return self._srate


class CplaybackClistSignalScompile(SCPICmdWrite, SCPICmdRead):
    """The ``CPLayback:CLISt:SIGNal:SCOMpile`` command.

    Description:
        - This command selects or deselects a signal from the captured signal list to be compiled.
          Single signals are selected with the command but more than one signal can be selected for
          compilation by sending multiple commands. Signals remain selected until deselected with
          this command. The query form returns the list of selected signals.

    Usage:
        - Using the ``.query()`` method will send the ``CPLayback:CLISt:SIGNal:SCOMpile?`` query.
        - Using the ``.verify(value)`` method will send the ``CPLayback:CLISt:SIGNal:SCOMpile?``
          query and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``CPLayback:CLISt:SIGNal:SCOMpile value``
          command.

    SCPI Syntax:
        ```
        - CPLayback:CLISt:SIGNal:SCOMpile <signal_name>,{OFF|ON|1|0}
        - CPLayback:CLISt:SIGNal:SCOMpile?
        ```

    Info:
        - ``*RST`` sets this to 0.
    """


class CplaybackClistSignalDelete(SCPICmdWrite):
    """The ``CPLayback:CLISt:SIGNal:DELete`` command.

    Description:
        - This command removes the specified signal from the Captured Signal List.

    Usage:
        - Using the ``.write(value)`` method will send the ``CPLayback:CLISt:SIGNal:DELete value``
          command.

    SCPI Syntax:
        ```
        - CPLayback:CLISt:SIGNal:DELete {ALL|signal_name}
        ```
    """


class CplaybackClistSignal(SCPICmdRead):
    """The ``CPLayback:CLISt:SIGNal`` command tree.

    Usage:
        - Using the ``.query()`` method will send the ``CPLayback:CLISt:SIGNal?`` query.
        - Using the ``.verify(value)`` method will send the ``CPLayback:CLISt:SIGNal?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.delete``: The ``CPLayback:CLISt:SIGNal:DELete`` command.
        - ``.scompile``: The ``CPLayback:CLISt:SIGNal:SCOMpile`` command.
        - ``.waveform``: The ``CPLayback:CLISt:SIGNal:WAVeform`` command tree.
        - ``.wcount``: The ``CPLayback:CLISt:SIGNal:WCOunt`` command.
    """

    def __init__(self, device: Optional["PIControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._delete = CplaybackClistSignalDelete(device, f"{self._cmd_syntax}:DELete")
        self._scompile = CplaybackClistSignalScompile(device, f"{self._cmd_syntax}:SCOMpile")
        self._waveform = CplaybackClistSignalWaveform(device, f"{self._cmd_syntax}:WAVeform")
        self._wcount = CplaybackClistSignalWcount(device, f"{self._cmd_syntax}:WCOunt")

    @property
    def delete(self) -> CplaybackClistSignalDelete:
        """Return the ``CPLayback:CLISt:SIGNal:DELete`` command.

        Description:
            - This command removes the specified signal from the Captured Signal List.

        Usage:
            - Using the ``.write(value)`` method will send the
              ``CPLayback:CLISt:SIGNal:DELete value`` command.

        SCPI Syntax:
            ```
            - CPLayback:CLISt:SIGNal:DELete {ALL|signal_name}
            ```
        """
        return self._delete

    @property
    def scompile(self) -> CplaybackClistSignalScompile:
        """Return the ``CPLayback:CLISt:SIGNal:SCOMpile`` command.

        Description:
            - This command selects or deselects a signal from the captured signal list to be
              compiled. Single signals are selected with the command but more than one signal can be
              selected for compilation by sending multiple commands. Signals remain selected until
              deselected with this command. The query form returns the list of selected signals.

        Usage:
            - Using the ``.query()`` method will send the ``CPLayback:CLISt:SIGNal:SCOMpile?``
              query.
            - Using the ``.verify(value)`` method will send the ``CPLayback:CLISt:SIGNal:SCOMpile?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the
              ``CPLayback:CLISt:SIGNal:SCOMpile value`` command.

        SCPI Syntax:
            ```
            - CPLayback:CLISt:SIGNal:SCOMpile <signal_name>,{OFF|ON|1|0}
            - CPLayback:CLISt:SIGNal:SCOMpile?
            ```

        Info:
            - ``*RST`` sets this to 0.
        """
        return self._scompile

    @property
    def waveform(self) -> CplaybackClistSignalWaveform:
        """Return the ``CPLayback:CLISt:SIGNal:WAVeform`` command tree.

        Usage:
            - Using the ``.query()`` method will send the ``CPLayback:CLISt:SIGNal:WAVeform?``
              query.
            - Using the ``.verify(value)`` method will send the ``CPLayback:CLISt:SIGNal:WAVeform?``
              query and raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.foffset``: The ``CPLayback:CLISt:SIGNal:WAVeform:FOFFset`` command.
            - ``.name``: The ``CPLayback:CLISt:SIGNal:WAVeform:NAME`` command.
            - ``.otime``: The ``CPLayback:CLISt:SIGNal:WAVeform:OTIMe`` command.
            - ``.srate``: The ``CPLayback:CLISt:SIGNal:WAVeform:SRATe`` command.
        """
        return self._waveform

    @property
    def wcount(self) -> CplaybackClistSignalWcount:
        """Return the ``CPLayback:CLISt:SIGNal:WCOunt`` command.

        Description:
            - This command returns the number of waveform segments in the specified signal in the
              Captured Signal List.

        Usage:
            - Using the ``.query(argument)`` method will send the
              ``CPLayback:CLISt:SIGNal:WCOunt? argument`` query.
            - Using the ``.verify(argument, value)`` method will send the
              ``CPLayback:CLISt:SIGNal:WCOunt? argument`` query and raise an AssertionError if the
              returned value does not match ``value``.

        SCPI Syntax:
            ```
            - CPLayback:CLISt:SIGNal:WCOunt? <signal_name>
            ```
        """
        return self._wcount


class CplaybackClistName(SCPICmdReadWithArguments):
    """The ``CPLayback:CLISt:NAME`` command.

    Description:
        - This command returns the name of a signal from the Captured Signal List in the position
          specified by the index value.

    Usage:
        - Using the ``.query(argument)`` method will send the ``CPLayback:CLISt:NAME? argument``
          query.
        - Using the ``.verify(argument, value)`` method will send the
          ``CPLayback:CLISt:NAME? argument`` query and raise an AssertionError if the returned value
          does not match ``value``.

    SCPI Syntax:
        ```
        - CPLayback:CLISt:NAME? <index>
        ```
    """


class CplaybackClist(SCPICmdRead):
    """The ``CPLayback:CLISt`` command tree.

    Usage:
        - Using the ``.query()`` method will send the ``CPLayback:CLISt?`` query.
        - Using the ``.verify(value)`` method will send the ``CPLayback:CLISt?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.name``: The ``CPLayback:CLISt:NAME`` command.
        - ``.signal``: The ``CPLayback:CLISt:SIGNal`` command tree.
        - ``.size``: The ``CPLayback:CLISt:SIZE`` command.
    """

    def __init__(self, device: Optional["PIControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._name = CplaybackClistName(device, f"{self._cmd_syntax}:NAME")
        self._signal = CplaybackClistSignal(device, f"{self._cmd_syntax}:SIGNal")
        self._size = CplaybackClistSize(device, f"{self._cmd_syntax}:SIZE")

    @property
    def name(self) -> CplaybackClistName:
        """Return the ``CPLayback:CLISt:NAME`` command.

        Description:
            - This command returns the name of a signal from the Captured Signal List in the
              position specified by the index value.

        Usage:
            - Using the ``.query(argument)`` method will send the ``CPLayback:CLISt:NAME? argument``
              query.
            - Using the ``.verify(argument, value)`` method will send the
              ``CPLayback:CLISt:NAME? argument`` query and raise an AssertionError if the returned
              value does not match ``value``.

        SCPI Syntax:
            ```
            - CPLayback:CLISt:NAME? <index>
            ```
        """
        return self._name

    @property
    def signal(self) -> CplaybackClistSignal:
        """Return the ``CPLayback:CLISt:SIGNal`` command tree.

        Usage:
            - Using the ``.query()`` method will send the ``CPLayback:CLISt:SIGNal?`` query.
            - Using the ``.verify(value)`` method will send the ``CPLayback:CLISt:SIGNal?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.delete``: The ``CPLayback:CLISt:SIGNal:DELete`` command.
            - ``.scompile``: The ``CPLayback:CLISt:SIGNal:SCOMpile`` command.
            - ``.waveform``: The ``CPLayback:CLISt:SIGNal:WAVeform`` command tree.
            - ``.wcount``: The ``CPLayback:CLISt:SIGNal:WCOunt`` command.
        """
        return self._signal

    @property
    def size(self) -> CplaybackClistSize:
        """Return the ``CPLayback:CLISt:SIZE`` command.

        Description:
            - This command returns the number of signals in the Captured Signal List.

        Usage:
            - Using the ``.query()`` method will send the ``CPLayback:CLISt:SIZE?`` query.
            - Using the ``.verify(value)`` method will send the ``CPLayback:CLISt:SIZE?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - CPLayback:CLISt:SIZE?
            ```
        """
        return self._size


class CplaybackCaptureWlist(SCPICmdWrite):
    """The ``CPLayback:CAPTure:WLISt`` command.

    Description:
        - This command adds the specified IQ waveform from the Waveform List to the specified signal
          in the Captured Signal List. If the specified signal does not exist, a new signal is
          created and added to the captured signal list.

    Usage:
        - Using the ``.write(value)`` method will send the ``CPLayback:CAPTure:WLISt value``
          command.

    SCPI Syntax:
        ```
        - CPLayback:CAPTure:WLISt <signal_name>,<waveform_name>
        ```
    """


class CplaybackCaptureInstrumentRsa(SCPICmdWrite):
    """The ``CPLayback:CAPTure:INSTrument:RSA`` command.

    Description:
        - This command connects to the specified RSA (Realtime Spectrum Analyzer), transfers the
          existing acquisition to the AWG, and adds it to the specified signal. If the specified
          signal does not exist, it is created and added to the captured signal list.

    Usage:
        - Using the ``.write(value)`` method will send the
          ``CPLayback:CAPTure:INSTrument:RSA value`` command.

    SCPI Syntax:
        ```
        - CPLayback:CAPTure:INSTrument:RSA <signal_name>,<instrument_name>
        ```
    """


class CplaybackCaptureInstrumentOscilloscope(SCPICmdWrite):
    """The ``CPLayback:CAPTure:INSTrument:OSCilloscope`` command.

    Description:
        - This command connects to the specified oscilloscope, transfers the existing acquisition
          from the oscilloscope to the AWG, and adds it to the specified signal. If the specified
          signal does not exist, it is created and added to the captured signal list.

    Usage:
        - Using the ``.write(value)`` method will send the
          ``CPLayback:CAPTure:INSTrument:OSCilloscope value`` command.

    SCPI Syntax:
        ```
        - CPLayback:CAPTure:INSTrument:OSCilloscope <signal_name>,<instrument_name>,<source_1>,<source_2>
        ```
    """  # noqa: E501


class CplaybackCaptureInstrument(SCPICmdRead):
    """The ``CPLayback:CAPTure:INSTrument`` command tree.

    Usage:
        - Using the ``.query()`` method will send the ``CPLayback:CAPTure:INSTrument?`` query.
        - Using the ``.verify(value)`` method will send the ``CPLayback:CAPTure:INSTrument?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.oscilloscope``: The ``CPLayback:CAPTure:INSTrument:OSCilloscope`` command.
        - ``.rsa``: The ``CPLayback:CAPTure:INSTrument:RSA`` command.
    """

    def __init__(self, device: Optional["PIControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._oscilloscope = CplaybackCaptureInstrumentOscilloscope(
            device, f"{self._cmd_syntax}:OSCilloscope"
        )
        self._rsa = CplaybackCaptureInstrumentRsa(device, f"{self._cmd_syntax}:RSA")

    @property
    def oscilloscope(self) -> CplaybackCaptureInstrumentOscilloscope:
        """Return the ``CPLayback:CAPTure:INSTrument:OSCilloscope`` command.

        Description:
            - This command connects to the specified oscilloscope, transfers the existing
              acquisition from the oscilloscope to the AWG, and adds it to the specified signal. If
              the specified signal does not exist, it is created and added to the captured signal
              list.

        Usage:
            - Using the ``.write(value)`` method will send the
              ``CPLayback:CAPTure:INSTrument:OSCilloscope value`` command.

        SCPI Syntax:
            ```
            - CPLayback:CAPTure:INSTrument:OSCilloscope <signal_name>,<instrument_name>,<source_1>,<source_2>
            ```
        """  # noqa: E501
        return self._oscilloscope

    @property
    def rsa(self) -> CplaybackCaptureInstrumentRsa:
        """Return the ``CPLayback:CAPTure:INSTrument:RSA`` command.

        Description:
            - This command connects to the specified RSA (Realtime Spectrum Analyzer), transfers the
              existing acquisition to the AWG, and adds it to the specified signal. If the specified
              signal does not exist, it is created and added to the captured signal list.

        Usage:
            - Using the ``.write(value)`` method will send the
              ``CPLayback:CAPTure:INSTrument:RSA value`` command.

        SCPI Syntax:
            ```
            - CPLayback:CAPTure:INSTrument:RSA <signal_name>,<instrument_name>
            ```
        """
        return self._rsa


class CplaybackCaptureFile(SCPICmdWrite):
    """The ``CPLayback:CAPTure:FILE`` command.

    Description:
        - The command imports baseband IQ waveform data and adds the waveform to the specified
          Signal Name in the captured signal list. If the specified Signal Name does not exist, it
          is created and added to the captured signal list. You can import a single IQ waveform,
          containing both the I and Q data, or you can import separate I and Q data files. When
          importing a single IQ waveform, the following file types are supported: .IQT - RSA3000
          Series waveform file format.TIQ - RSA6000 Series waveform file format.MAT - MATLAB file
          format.TMP - Midas Blue file format.PRM - Midas Blue file format When importing individual
          I and Q data files, the following file types are supported: .WFMX - AWG70000 Series
          waveform file format.TXT - AWG400/AWG500/AWG600/AWG700/AWG5000/AWG7000 Series waveform.WFM
          - AWG400/AWG500/AWG600/AWG700/AWG5000/AWG7000 Series waveform.MAT - MATLAB file format.RFD
          - RFXpress waveform file format

    Usage:
        - Using the ``.write(value)`` method will send the ``CPLayback:CAPTure:FILE value`` command.

    SCPI Syntax:
        ```
        - CPLayback:CAPTure:FILE <signal_name>,{SIQ|CIQ},<file_path>[,<file_path>]
        ```
    """


class CplaybackCapture(SCPICmdRead):
    """The ``CPLayback:CAPTure`` command tree.

    Usage:
        - Using the ``.query()`` method will send the ``CPLayback:CAPTure?`` query.
        - Using the ``.verify(value)`` method will send the ``CPLayback:CAPTure?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.file``: The ``CPLayback:CAPTure:FILE`` command.
        - ``.instrument``: The ``CPLayback:CAPTure:INSTrument`` command tree.
        - ``.wlist``: The ``CPLayback:CAPTure:WLISt`` command.
    """

    def __init__(self, device: Optional["PIControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._file = CplaybackCaptureFile(device, f"{self._cmd_syntax}:FILE")
        self._instrument = CplaybackCaptureInstrument(device, f"{self._cmd_syntax}:INSTrument")
        self._wlist = CplaybackCaptureWlist(device, f"{self._cmd_syntax}:WLISt")

    @property
    def file(self) -> CplaybackCaptureFile:
        """Return the ``CPLayback:CAPTure:FILE`` command.

        Description:
            - The command imports baseband IQ waveform data and adds the waveform to the specified
              Signal Name in the captured signal list. If the specified Signal Name does not exist,
              it is created and added to the captured signal list. You can import a single IQ
              waveform, containing both the I and Q data, or you can import separate I and Q data
              files. When importing a single IQ waveform, the following file types are supported:
              .IQT - RSA3000 Series waveform file format.TIQ - RSA6000 Series waveform file
              format.MAT - MATLAB file format.TMP - Midas Blue file format.PRM - Midas Blue file
              format When importing individual I and Q data files, the following file types are
              supported: .WFMX - AWG70000 Series waveform file format.TXT -
              AWG400/AWG500/AWG600/AWG700/AWG5000/AWG7000 Series waveform.WFM -
              AWG400/AWG500/AWG600/AWG700/AWG5000/AWG7000 Series waveform.MAT - MATLAB file
              format.RFD - RFXpress waveform file format

        Usage:
            - Using the ``.write(value)`` method will send the ``CPLayback:CAPTure:FILE value``
              command.

        SCPI Syntax:
            ```
            - CPLayback:CAPTure:FILE <signal_name>,{SIQ|CIQ},<file_path>[,<file_path>]
            ```
        """
        return self._file

    @property
    def instrument(self) -> CplaybackCaptureInstrument:
        """Return the ``CPLayback:CAPTure:INSTrument`` command tree.

        Usage:
            - Using the ``.query()`` method will send the ``CPLayback:CAPTure:INSTrument?`` query.
            - Using the ``.verify(value)`` method will send the ``CPLayback:CAPTure:INSTrument?``
              query and raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.oscilloscope``: The ``CPLayback:CAPTure:INSTrument:OSCilloscope`` command.
            - ``.rsa``: The ``CPLayback:CAPTure:INSTrument:RSA`` command.
        """
        return self._instrument

    @property
    def wlist(self) -> CplaybackCaptureWlist:
        """Return the ``CPLayback:CAPTure:WLISt`` command.

        Description:
            - This command adds the specified IQ waveform from the Waveform List to the specified
              signal in the Captured Signal List. If the specified signal does not exist, a new
              signal is created and added to the captured signal list.

        Usage:
            - Using the ``.write(value)`` method will send the ``CPLayback:CAPTure:WLISt value``
              command.

        SCPI Syntax:
            ```
            - CPLayback:CAPTure:WLISt <signal_name>,<waveform_name>
            ```
        """
        return self._wlist


class Cplayback(SCPICmdRead):
    """The ``CPLayback`` command tree.

    Usage:
        - Using the ``.query()`` method will send the ``CPLayback?`` query.
        - Using the ``.verify(value)`` method will send the ``CPLayback?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.capture``: The ``CPLayback:CAPTure`` command tree.
        - ``.clist``: The ``CPLayback:CLISt`` command tree.
        - ``.compile``: The ``CPLayback:COMPile`` command.
    """

    def __init__(self, device: Optional["PIControl"] = None, cmd_syntax: str = "CPLayback") -> None:
        super().__init__(device, cmd_syntax)
        self._capture = CplaybackCapture(device, f"{self._cmd_syntax}:CAPTure")
        self._clist = CplaybackClist(device, f"{self._cmd_syntax}:CLISt")
        self._compile = CplaybackCompile(device, f"{self._cmd_syntax}:COMPile")

    @property
    def capture(self) -> CplaybackCapture:
        """Return the ``CPLayback:CAPTure`` command tree.

        Usage:
            - Using the ``.query()`` method will send the ``CPLayback:CAPTure?`` query.
            - Using the ``.verify(value)`` method will send the ``CPLayback:CAPTure?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.file``: The ``CPLayback:CAPTure:FILE`` command.
            - ``.instrument``: The ``CPLayback:CAPTure:INSTrument`` command tree.
            - ``.wlist``: The ``CPLayback:CAPTure:WLISt`` command.
        """
        return self._capture

    @property
    def clist(self) -> CplaybackClist:
        """Return the ``CPLayback:CLISt`` command tree.

        Usage:
            - Using the ``.query()`` method will send the ``CPLayback:CLISt?`` query.
            - Using the ``.verify(value)`` method will send the ``CPLayback:CLISt?`` query and raise
              an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.name``: The ``CPLayback:CLISt:NAME`` command.
            - ``.signal``: The ``CPLayback:CLISt:SIGNal`` command tree.
            - ``.size``: The ``CPLayback:CLISt:SIZE`` command.
        """
        return self._clist

    @property
    def compile(self) -> CplaybackCompile:
        """Return the ``CPLayback:COMPile`` command.

        Description:
            - The command resamples and upconverts the selected signal to the specified carrier
              frequency. With Option 03 (Sequencing) enabled: A sequence is generated containing all
              waveform segments in the signal (even if the signal contains only one waveform
              segment. Without Option 03 (Sequencing): A waveform is generated if there is only one
              waveform segment in the signal. If the signal contains multiple waveform segments, the
              compile fails and an error message is generated. You can select to compile more than
              one signal at a time. The compile process generates a sequence (or waveform) for each
              of the selected signals.

        Usage:
            - Using the ``.write()`` method will send the ``CPLayback:COMPile`` command.

        SCPI Syntax:
            ```
            - CPLayback:COMPile
            ```

        Sub-properties:
            - ``.cfrequency``: The ``CPLayback:COMPile:CFRequency`` command.
            - ``.lsequence``: The ``CPLayback:COMPile:LSEQuence`` command.
            - ``.normalize``: The ``CPLayback:COMPile:NORMalize`` command.
            - ``.srate``: The ``CPLayback:COMPile:SRATe`` command.
        """
        return self._compile



"""The calibration commands module.

These commands are used in the following models:
DPO7AX, LPD6, MSO4, MSO4B, MSO5, MSO5B, MSO5LP, MSO6, MSO6B

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:
    ```
    - *CAL?
    ```
"""

from typing import Optional, TYPE_CHECKING

from ..helpers import SCPICmdRead

if TYPE_CHECKING:
    from tm_devices.driver_mixins.device_control.pi_control import PIControl


class Cal(SCPICmdRead):
    """The ``*CAL`` command.

    Description:
        - This query-only command starts signal path calibration (SPC) and returns the status upon
          completion. Note: When running SPC through the remote interface, calibration status cannot
          be obtained until after the SPC completes. SPC takes approximately 15 minutes per channel
          which means a total of 2 hours on an 8-channel model. Any remote command that performs an
          action on the instrument is also disabled until the SPC is complete.

    Usage:
        - Using the ``.query()`` method will send the ``*CAL?`` query.
        - Using the ``.verify(value)`` method will send the ``*CAL?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - *CAL?
        ```
    """

    def __init__(self, device: Optional["PIControl"] = None, cmd_syntax: str = "*CAL") -> None:
        super().__init__(device, cmd_syntax)
